from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Direct3D
import win32more.Windows.Win32.Graphics.Direct3D10
import win32more.Windows.Win32.Graphics.Dxgi
import win32more.Windows.Win32.Graphics.Dxgi.Common
import win32more.Windows.Win32.System.Com
D3D10_16BIT_INDEX_STRIP_CUT_VALUE: UInt32 = 65535
D3D10_32BIT_INDEX_STRIP_CUT_VALUE: UInt32 = 4294967295
D3D10_8BIT_INDEX_STRIP_CUT_VALUE: UInt32 = 255
D3D10_ARRAY_AXIS_ADDRESS_RANGE_BIT_COUNT: UInt32 = 9
D3D10_CLIP_OR_CULL_DISTANCE_COUNT: UInt32 = 8
D3D10_CLIP_OR_CULL_DISTANCE_ELEMENT_COUNT: UInt32 = 2
D3D10_COMMONSHADER_CONSTANT_BUFFER_API_SLOT_COUNT: UInt32 = 14
D3D10_COMMONSHADER_CONSTANT_BUFFER_COMPONENTS: UInt32 = 4
D3D10_COMMONSHADER_CONSTANT_BUFFER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_COMMONSHADER_CONSTANT_BUFFER_HW_SLOT_COUNT: UInt32 = 15
D3D10_COMMONSHADER_CONSTANT_BUFFER_REGISTER_COMPONENTS: UInt32 = 4
D3D10_COMMONSHADER_CONSTANT_BUFFER_REGISTER_COUNT: UInt32 = 15
D3D10_COMMONSHADER_CONSTANT_BUFFER_REGISTER_READS_PER_INST: UInt32 = 1
D3D10_COMMONSHADER_CONSTANT_BUFFER_REGISTER_READ_PORTS: UInt32 = 1
D3D10_COMMONSHADER_FLOWCONTROL_NESTING_LIMIT: UInt32 = 64
D3D10_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_COMPONENTS: UInt32 = 4
D3D10_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_COUNT: UInt32 = 1
D3D10_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_READS_PER_INST: UInt32 = 1
D3D10_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_READ_PORTS: UInt32 = 1
D3D10_COMMONSHADER_IMMEDIATE_VALUE_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_COMMONSHADER_INPUT_RESOURCE_REGISTER_COMPONENTS: UInt32 = 1
D3D10_COMMONSHADER_INPUT_RESOURCE_REGISTER_COUNT: UInt32 = 128
D3D10_COMMONSHADER_INPUT_RESOURCE_REGISTER_READS_PER_INST: UInt32 = 1
D3D10_COMMONSHADER_INPUT_RESOURCE_REGISTER_READ_PORTS: UInt32 = 1
D3D10_COMMONSHADER_INPUT_RESOURCE_SLOT_COUNT: UInt32 = 128
D3D10_COMMONSHADER_SAMPLER_REGISTER_COMPONENTS: UInt32 = 1
D3D10_COMMONSHADER_SAMPLER_REGISTER_COUNT: UInt32 = 16
D3D10_COMMONSHADER_SAMPLER_REGISTER_READS_PER_INST: UInt32 = 1
D3D10_COMMONSHADER_SAMPLER_REGISTER_READ_PORTS: UInt32 = 1
D3D10_COMMONSHADER_SAMPLER_SLOT_COUNT: UInt32 = 16
D3D10_COMMONSHADER_SUBROUTINE_NESTING_LIMIT: UInt32 = 32
D3D10_COMMONSHADER_TEMP_REGISTER_COMPONENTS: UInt32 = 4
D3D10_COMMONSHADER_TEMP_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_COMMONSHADER_TEMP_REGISTER_COUNT: UInt32 = 4096
D3D10_COMMONSHADER_TEMP_REGISTER_READS_PER_INST: UInt32 = 3
D3D10_COMMONSHADER_TEMP_REGISTER_READ_PORTS: UInt32 = 3
D3D10_COMMONSHADER_TEXCOORD_RANGE_REDUCTION_MAX: UInt32 = 10
D3D10_COMMONSHADER_TEXCOORD_RANGE_REDUCTION_MIN: Int32 = -10
D3D10_COMMONSHADER_TEXEL_OFFSET_MAX_NEGATIVE: Int32 = -8
D3D10_COMMONSHADER_TEXEL_OFFSET_MAX_POSITIVE: UInt32 = 7
D3D10_DEFAULT_BLEND_FACTOR_ALPHA: Single = 1
D3D10_DEFAULT_BLEND_FACTOR_BLUE: Single = 1
D3D10_DEFAULT_BLEND_FACTOR_GREEN: Single = 1
D3D10_DEFAULT_BLEND_FACTOR_RED: Single = 1
D3D10_DEFAULT_BORDER_COLOR_COMPONENT: Single = 0
D3D10_DEFAULT_DEPTH_BIAS: UInt32 = 0
D3D10_DEFAULT_DEPTH_BIAS_CLAMP: Single = 0
D3D10_DEFAULT_MAX_ANISOTROPY: Single = 16
D3D10_DEFAULT_MIP_LOD_BIAS: Single = 0
D3D10_DEFAULT_RENDER_TARGET_ARRAY_INDEX: UInt32 = 0
D3D10_DEFAULT_SAMPLE_MASK: UInt32 = 4294967295
D3D10_DEFAULT_SCISSOR_ENDX: UInt32 = 0
D3D10_DEFAULT_SCISSOR_ENDY: UInt32 = 0
D3D10_DEFAULT_SCISSOR_STARTX: UInt32 = 0
D3D10_DEFAULT_SCISSOR_STARTY: UInt32 = 0
D3D10_DEFAULT_SLOPE_SCALED_DEPTH_BIAS: Single = 0
D3D10_DEFAULT_STENCIL_READ_MASK: UInt32 = 255
D3D10_DEFAULT_STENCIL_REFERENCE: UInt32 = 0
D3D10_DEFAULT_STENCIL_WRITE_MASK: UInt32 = 255
D3D10_DEFAULT_VIEWPORT_AND_SCISSORRECT_INDEX: UInt32 = 0
D3D10_DEFAULT_VIEWPORT_HEIGHT: UInt32 = 0
D3D10_DEFAULT_VIEWPORT_MAX_DEPTH: Single = 0
D3D10_DEFAULT_VIEWPORT_MIN_DEPTH: Single = 0
D3D10_DEFAULT_VIEWPORT_TOPLEFTX: UInt32 = 0
D3D10_DEFAULT_VIEWPORT_TOPLEFTY: UInt32 = 0
D3D10_DEFAULT_VIEWPORT_WIDTH: UInt32 = 0
D3D10_FLOAT16_FUSED_TOLERANCE_IN_ULP: Double = 0.6
D3D10_FLOAT32_MAX: Single = 3.4028235e+38
D3D10_FLOAT32_TO_INTEGER_TOLERANCE_IN_ULP: Single = 0.6
D3D10_FLOAT_TO_SRGB_EXPONENT_DENOMINATOR: Single = 2.4
D3D10_FLOAT_TO_SRGB_EXPONENT_NUMERATOR: Single = 1
D3D10_FLOAT_TO_SRGB_OFFSET: Single = 0.055
D3D10_FLOAT_TO_SRGB_SCALE_1: Single = 12.92
D3D10_FLOAT_TO_SRGB_SCALE_2: Single = 1.055
D3D10_FLOAT_TO_SRGB_THRESHOLD: Single = 0.0031308
D3D10_FTOI_INSTRUCTION_MAX_INPUT: Single = 2147483600.0
D3D10_FTOI_INSTRUCTION_MIN_INPUT: Single = -2147483600.0
D3D10_FTOU_INSTRUCTION_MAX_INPUT: Single = 4294967300.0
D3D10_FTOU_INSTRUCTION_MIN_INPUT: Single = 0
D3D10_GS_INPUT_PRIM_CONST_REGISTER_COMPONENTS: UInt32 = 1
D3D10_GS_INPUT_PRIM_CONST_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_GS_INPUT_PRIM_CONST_REGISTER_COUNT: UInt32 = 1
D3D10_GS_INPUT_PRIM_CONST_REGISTER_READS_PER_INST: UInt32 = 2
D3D10_GS_INPUT_PRIM_CONST_REGISTER_READ_PORTS: UInt32 = 1
D3D10_GS_INPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D10_GS_INPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_GS_INPUT_REGISTER_COUNT: UInt32 = 16
D3D10_GS_INPUT_REGISTER_READS_PER_INST: UInt32 = 2
D3D10_GS_INPUT_REGISTER_READ_PORTS: UInt32 = 1
D3D10_GS_INPUT_REGISTER_VERTICES: UInt32 = 6
D3D10_GS_OUTPUT_ELEMENTS: UInt32 = 32
D3D10_GS_OUTPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D10_GS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_GS_OUTPUT_REGISTER_COUNT: UInt32 = 32
D3D10_IA_DEFAULT_INDEX_BUFFER_OFFSET_IN_BYTES: UInt32 = 0
D3D10_IA_DEFAULT_PRIMITIVE_TOPOLOGY: UInt32 = 0
D3D10_IA_DEFAULT_VERTEX_BUFFER_OFFSET_IN_BYTES: UInt32 = 0
D3D10_IA_INDEX_INPUT_RESOURCE_SLOT_COUNT: UInt32 = 1
D3D10_IA_INSTANCE_ID_BIT_COUNT: UInt32 = 32
D3D10_IA_INTEGER_ARITHMETIC_BIT_COUNT: UInt32 = 32
D3D10_IA_PRIMITIVE_ID_BIT_COUNT: UInt32 = 32
D3D10_IA_VERTEX_ID_BIT_COUNT: UInt32 = 32
D3D10_IA_VERTEX_INPUT_RESOURCE_SLOT_COUNT: UInt32 = 16
D3D10_IA_VERTEX_INPUT_STRUCTURE_ELEMENTS_COMPONENTS: UInt32 = 64
D3D10_IA_VERTEX_INPUT_STRUCTURE_ELEMENT_COUNT: UInt32 = 16
D3D10_INTEGER_DIVIDE_BY_ZERO_QUOTIENT: UInt32 = 4294967295
D3D10_INTEGER_DIVIDE_BY_ZERO_REMAINDER: UInt32 = 4294967295
D3D10_LINEAR_GAMMA: Single = 1
D3D10_MAX_BORDER_COLOR_COMPONENT: Single = 1
D3D10_MAX_DEPTH: Single = 1
D3D10_MAX_MAXANISOTROPY: UInt32 = 16
D3D10_MAX_MULTISAMPLE_SAMPLE_COUNT: UInt32 = 32
D3D10_MAX_POSITION_VALUE: Single = 3.4028236e+34
D3D10_MAX_TEXTURE_DIMENSION_2_TO_EXP: UInt32 = 17
D3D10_MIN_BORDER_COLOR_COMPONENT: Single = 0
D3D10_MIN_DEPTH: Single = 0
D3D10_MIN_MAXANISOTROPY: UInt32 = 0
D3D10_MIP_LOD_BIAS_MAX: Single = 15.99
D3D10_MIP_LOD_BIAS_MIN: Single = -16
D3D10_MIP_LOD_FRACTIONAL_BIT_COUNT: UInt32 = 6
D3D10_MIP_LOD_RANGE_BIT_COUNT: UInt32 = 8
D3D10_MULTISAMPLE_ANTIALIAS_LINE_WIDTH: Single = 1.4
D3D10_NONSAMPLE_FETCH_OUT_OF_RANGE_ACCESS_RESULT: UInt32 = 0
D3D10_PIXEL_ADDRESS_RANGE_BIT_COUNT: UInt32 = 13
D3D10_PRE_SCISSOR_PIXEL_ADDRESS_RANGE_BIT_COUNT: UInt32 = 15
D3D10_PS_FRONTFACING_DEFAULT_VALUE: UInt32 = 4294967295
D3D10_PS_FRONTFACING_FALSE_VALUE: UInt32 = 0
D3D10_PS_FRONTFACING_TRUE_VALUE: UInt32 = 4294967295
D3D10_PS_INPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D10_PS_INPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_PS_INPUT_REGISTER_COUNT: UInt32 = 32
D3D10_PS_INPUT_REGISTER_READS_PER_INST: UInt32 = 2
D3D10_PS_INPUT_REGISTER_READ_PORTS: UInt32 = 1
D3D10_PS_LEGACY_PIXEL_CENTER_FRACTIONAL_COMPONENT: Single = 0
D3D10_PS_OUTPUT_DEPTH_REGISTER_COMPONENTS: UInt32 = 1
D3D10_PS_OUTPUT_DEPTH_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_PS_OUTPUT_DEPTH_REGISTER_COUNT: UInt32 = 1
D3D10_PS_OUTPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D10_PS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_PS_OUTPUT_REGISTER_COUNT: UInt32 = 8
D3D10_PS_PIXEL_CENTER_FRACTIONAL_COMPONENT: Single = 0.5
D3D10_REQ_BLEND_OBJECT_COUNT_PER_CONTEXT: UInt32 = 4096
D3D10_REQ_BUFFER_RESOURCE_TEXEL_COUNT_2_TO_EXP: UInt32 = 27
D3D10_REQ_CONSTANT_BUFFER_ELEMENT_COUNT: UInt32 = 4096
D3D10_REQ_DEPTH_STENCIL_OBJECT_COUNT_PER_CONTEXT: UInt32 = 4096
D3D10_REQ_DRAWINDEXED_INDEX_COUNT_2_TO_EXP: UInt32 = 32
D3D10_REQ_DRAW_VERTEX_COUNT_2_TO_EXP: UInt32 = 32
D3D10_REQ_FILTERING_HW_ADDRESSABLE_RESOURCE_DIMENSION: UInt32 = 8192
D3D10_REQ_GS_INVOCATION_32BIT_OUTPUT_COMPONENT_LIMIT: UInt32 = 1024
D3D10_REQ_IMMEDIATE_CONSTANT_BUFFER_ELEMENT_COUNT: UInt32 = 4096
D3D10_REQ_MAXANISOTROPY: UInt32 = 16
D3D10_REQ_MIP_LEVELS: UInt32 = 14
D3D10_REQ_MULTI_ELEMENT_STRUCTURE_SIZE_IN_BYTES: UInt32 = 2048
D3D10_REQ_RASTERIZER_OBJECT_COUNT_PER_CONTEXT: UInt32 = 4096
D3D10_REQ_RENDER_TO_BUFFER_WINDOW_WIDTH: UInt32 = 8192
D3D10_REQ_RESOURCE_SIZE_IN_MEGABYTES: UInt32 = 128
D3D10_REQ_RESOURCE_VIEW_COUNT_PER_CONTEXT_2_TO_EXP: UInt32 = 20
D3D10_REQ_SAMPLER_OBJECT_COUNT_PER_CONTEXT: UInt32 = 4096
D3D10_REQ_TEXTURE1D_ARRAY_AXIS_DIMENSION: UInt32 = 512
D3D10_REQ_TEXTURE1D_U_DIMENSION: UInt32 = 8192
D3D10_REQ_TEXTURE2D_ARRAY_AXIS_DIMENSION: UInt32 = 512
D3D10_REQ_TEXTURE2D_U_OR_V_DIMENSION: UInt32 = 8192
D3D10_REQ_TEXTURE3D_U_V_OR_W_DIMENSION: UInt32 = 2048
D3D10_REQ_TEXTURECUBE_DIMENSION: UInt32 = 8192
D3D10_RESINFO_INSTRUCTION_MISSING_COMPONENT_RETVAL: UInt32 = 0
D3D10_SHADER_MAJOR_VERSION: UInt32 = 4
D3D10_SHADER_MINOR_VERSION: UInt32 = 0
D3D10_SHIFT_INSTRUCTION_PAD_VALUE: UInt32 = 0
D3D10_SHIFT_INSTRUCTION_SHIFT_VALUE_BIT_COUNT: UInt32 = 5
D3D10_SIMULTANEOUS_RENDER_TARGET_COUNT: UInt32 = 8
D3D10_SO_BUFFER_MAX_STRIDE_IN_BYTES: UInt32 = 2048
D3D10_SO_BUFFER_MAX_WRITE_WINDOW_IN_BYTES: UInt32 = 256
D3D10_SO_BUFFER_SLOT_COUNT: UInt32 = 4
D3D10_SO_DDI_REGISTER_INDEX_DENOTING_GAP: UInt32 = 4294967295
D3D10_SO_MULTIPLE_BUFFER_ELEMENTS_PER_BUFFER: UInt32 = 1
D3D10_SO_SINGLE_BUFFER_COMPONENT_LIMIT: UInt32 = 64
D3D10_SRGB_GAMMA: Single = 2.2
D3D10_SRGB_TO_FLOAT_DENOMINATOR_1: Single = 12.92
D3D10_SRGB_TO_FLOAT_DENOMINATOR_2: Single = 1.055
D3D10_SRGB_TO_FLOAT_EXPONENT: Single = 2.4
D3D10_SRGB_TO_FLOAT_OFFSET: Single = 0.055
D3D10_SRGB_TO_FLOAT_THRESHOLD: Single = 0.04045
D3D10_SRGB_TO_FLOAT_TOLERANCE_IN_ULP: Single = 0.5
D3D10_STANDARD_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_STANDARD_COMPONENT_BIT_COUNT_DOUBLED: UInt32 = 64
D3D10_STANDARD_MAXIMUM_ELEMENT_ALIGNMENT_BYTE_MULTIPLE: UInt32 = 4
D3D10_STANDARD_PIXEL_COMPONENT_COUNT: UInt32 = 128
D3D10_STANDARD_PIXEL_ELEMENT_COUNT: UInt32 = 32
D3D10_STANDARD_VECTOR_SIZE: UInt32 = 4
D3D10_STANDARD_VERTEX_ELEMENT_COUNT: UInt32 = 16
D3D10_STANDARD_VERTEX_TOTAL_COMPONENT_COUNT: UInt32 = 64
D3D10_SUBPIXEL_FRACTIONAL_BIT_COUNT: UInt32 = 8
D3D10_SUBTEXEL_FRACTIONAL_BIT_COUNT: UInt32 = 6
D3D10_TEXEL_ADDRESS_RANGE_BIT_COUNT: UInt32 = 18
D3D10_UNBOUND_MEMORY_ACCESS_RESULT: UInt32 = 0
D3D10_VIEWPORT_AND_SCISSORRECT_MAX_INDEX: UInt32 = 15
D3D10_VIEWPORT_AND_SCISSORRECT_OBJECT_COUNT_PER_PIPELINE: UInt32 = 16
D3D10_VIEWPORT_BOUNDS_MAX: UInt32 = 16383
D3D10_VIEWPORT_BOUNDS_MIN: Int32 = -16384
D3D10_VS_INPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D10_VS_INPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_VS_INPUT_REGISTER_COUNT: UInt32 = 16
D3D10_VS_INPUT_REGISTER_READS_PER_INST: UInt32 = 2
D3D10_VS_INPUT_REGISTER_READ_PORTS: UInt32 = 1
D3D10_VS_OUTPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D10_VS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_VS_OUTPUT_REGISTER_COUNT: UInt32 = 16
D3D10_WHQL_CONTEXT_COUNT_FOR_RESOURCE_LIMIT: UInt32 = 10
D3D10_WHQL_DRAWINDEXED_INDEX_COUNT_2_TO_EXP: UInt32 = 25
D3D10_WHQL_DRAW_VERTEX_COUNT_2_TO_EXP: UInt32 = 25
D3D_MAJOR_VERSION: UInt32 = 10
D3D_MINOR_VERSION: UInt32 = 0
D3D_SPEC_DATE_DAY: UInt32 = 8
D3D_SPEC_DATE_MONTH: UInt32 = 8
D3D_SPEC_DATE_YEAR: UInt32 = 2006
D3D_SPEC_VERSION: Double = 1.050005
D3D10_1_IA_VERTEX_INPUT_STRUCTURE_ELEMENT_COUNT: UInt32 = 16
D3D10_1_IA_VERTEX_INPUT_RESOURCE_SLOT_COUNT: UInt32 = 16
_FACD3D10: UInt32 = 2169
D3D10_APPEND_ALIGNED_ELEMENT: UInt32 = 4294967295
D3D10_FILTER_TYPE_MASK: UInt32 = 3
D3D10_MIN_FILTER_SHIFT: UInt32 = 4
D3D10_MAG_FILTER_SHIFT: UInt32 = 2
D3D10_MIP_FILTER_SHIFT: UInt32 = 0
D3D10_COMPARISON_FILTERING_BIT: UInt32 = 128
D3D10_ANISOTROPIC_FILTERING_BIT: UInt32 = 64
D3D10_TEXT_1BIT_BIT: UInt32 = 2147483648
D3D10_SDK_VERSION: UInt32 = 29
D3D10_1_DEFAULT_SAMPLE_MASK: UInt32 = 4294967295
D3D10_1_FLOAT16_FUSED_TOLERANCE_IN_ULP: Double = 0.6
D3D10_1_FLOAT32_TO_INTEGER_TOLERANCE_IN_ULP: Single = 0.6
D3D10_1_GS_INPUT_REGISTER_COUNT: UInt32 = 32
D3D10_1_IA_VERTEX_INPUT_STRUCTURE_ELEMENTS_COMPONENTS: UInt32 = 128
D3D10_1_PS_OUTPUT_MASK_REGISTER_COMPONENTS: UInt32 = 1
D3D10_1_PS_OUTPUT_MASK_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D10_1_PS_OUTPUT_MASK_REGISTER_COUNT: UInt32 = 1
D3D10_1_SHADER_MAJOR_VERSION: UInt32 = 4
D3D10_1_SHADER_MINOR_VERSION: UInt32 = 1
D3D10_1_SO_BUFFER_MAX_STRIDE_IN_BYTES: UInt32 = 2048
D3D10_1_SO_BUFFER_MAX_WRITE_WINDOW_IN_BYTES: UInt32 = 256
D3D10_1_SO_BUFFER_SLOT_COUNT: UInt32 = 4
D3D10_1_SO_MULTIPLE_BUFFER_ELEMENTS_PER_BUFFER: UInt32 = 1
D3D10_1_SO_SINGLE_BUFFER_COMPONENT_LIMIT: UInt32 = 64
D3D10_1_STANDARD_VERTEX_ELEMENT_COUNT: UInt32 = 32
D3D10_1_SUBPIXEL_FRACTIONAL_BIT_COUNT: UInt32 = 8
D3D10_1_VS_INPUT_REGISTER_COUNT: UInt32 = 32
D3D10_1_VS_OUTPUT_REGISTER_COUNT: UInt32 = 32
D3D10_SDK_LAYERS_VERSION: UInt32 = 11
D3D10_DEBUG_FEATURE_FLUSH_PER_RENDER_OP: UInt32 = 1
D3D10_DEBUG_FEATURE_FINISH_PER_RENDER_OP: UInt32 = 2
D3D10_DEBUG_FEATURE_PRESENT_PER_RENDER_OP: UInt32 = 4
DXGI_DEBUG_D3D10: Guid = Guid('{243b4c52-3606-4d3a-99d7-a7e7b33ed706}')
D3D10_REGKEY_PATH: String = 'Software\\Microsoft\\Direct3D'
D3D10_MUTE_DEBUG_OUTPUT: String = 'MuteDebugOutput'
D3D10_ENABLE_BREAK_ON_MESSAGE: String = 'EnableBreakOnMessage'
D3D10_INFOQUEUE_STORAGE_FILTER_OVERRIDE: String = 'InfoQueueStorageFilterOverride'
D3D10_MUTE_CATEGORY: String = 'Mute_CATEGORY_%s'
D3D10_MUTE_SEVERITY: String = 'Mute_SEVERITY_%s'
D3D10_MUTE_ID_STRING: String = 'Mute_ID_%s'
D3D10_MUTE_ID_DECIMAL: String = 'Mute_ID_%d'
D3D10_UNMUTE_SEVERITY_INFO: String = 'Unmute_SEVERITY_INFO'
D3D10_BREAKON_CATEGORY: String = 'BreakOn_CATEGORY_%s'
D3D10_BREAKON_SEVERITY: String = 'BreakOn_SEVERITY_%s'
D3D10_BREAKON_ID_STRING: String = 'BreakOn_ID_%s'
D3D10_BREAKON_ID_DECIMAL: String = 'BreakOn_ID_%d'
D3D10_APPSIZE_STRING: String = 'Size'
D3D10_APPNAME_STRING: String = 'Name'
D3D10_INFO_QUEUE_DEFAULT_MESSAGE_COUNT_LIMIT: UInt32 = 1024
D3D10_SHADER_DEBUG: UInt32 = 1
D3D10_SHADER_SKIP_VALIDATION: UInt32 = 2
D3D10_SHADER_SKIP_OPTIMIZATION: UInt32 = 4
D3D10_SHADER_PACK_MATRIX_ROW_MAJOR: UInt32 = 8
D3D10_SHADER_PACK_MATRIX_COLUMN_MAJOR: UInt32 = 16
D3D10_SHADER_PARTIAL_PRECISION: UInt32 = 32
D3D10_SHADER_FORCE_VS_SOFTWARE_NO_OPT: UInt32 = 64
D3D10_SHADER_FORCE_PS_SOFTWARE_NO_OPT: UInt32 = 128
D3D10_SHADER_NO_PRESHADER: UInt32 = 256
D3D10_SHADER_AVOID_FLOW_CONTROL: UInt32 = 512
D3D10_SHADER_PREFER_FLOW_CONTROL: UInt32 = 1024
D3D10_SHADER_ENABLE_STRICTNESS: UInt32 = 2048
D3D10_SHADER_ENABLE_BACKWARDS_COMPATIBILITY: UInt32 = 4096
D3D10_SHADER_IEEE_STRICTNESS: UInt32 = 8192
D3D10_SHADER_WARNINGS_ARE_ERRORS: UInt32 = 262144
D3D10_SHADER_RESOURCES_MAY_ALIAS: UInt32 = 524288
D3D10_ENABLE_UNBOUNDED_DESCRIPTOR_TABLES: UInt32 = 1048576
D3D10_ALL_RESOURCES_BOUND: UInt32 = 2097152
D3D10_SHADER_DEBUG_NAME_FOR_SOURCE: UInt32 = 4194304
D3D10_SHADER_DEBUG_NAME_FOR_BINARY: UInt32 = 8388608
D3D10_SHADER_OPTIMIZATION_LEVEL0: UInt32 = 16384
D3D10_SHADER_OPTIMIZATION_LEVEL1: UInt32 = 0
D3D10_SHADER_OPTIMIZATION_LEVEL3: UInt32 = 32768
D3D10_SHADER_FLAGS2_FORCE_ROOT_SIGNATURE_LATEST: UInt32 = 0
D3D10_SHADER_FLAGS2_FORCE_ROOT_SIGNATURE_1_0: UInt32 = 16
D3D10_SHADER_FLAGS2_FORCE_ROOT_SIGNATURE_1_1: UInt32 = 32
D3D10_EFFECT_COMPILE_CHILD_EFFECT: UInt32 = 1
D3D10_EFFECT_COMPILE_ALLOW_SLOW_OPS: UInt32 = 2
D3D10_EFFECT_SINGLE_THREADED: UInt32 = 8
D3D10_EFFECT_VARIABLE_POOLED: UInt32 = 1
D3D10_EFFECT_VARIABLE_ANNOTATION: UInt32 = 2
D3D10_EFFECT_VARIABLE_EXPLICIT_BIND_POINT: UInt32 = 4
GUID_DeviceType: Guid = Guid('{d722fb4d-7a68-437a-b20c-5804ee2494a6}')
@winfunctype('d3d10.dll')
def D3D10CreateDevice(pAdapter: win32more.Windows.Win32.Graphics.Dxgi.IDXGIAdapter, DriverType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DRIVER_TYPE, Software: win32more.Windows.Win32.Foundation.HMODULE, Flags: UInt32, SDKVersion: UInt32, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10CreateDeviceAndSwapChain(pAdapter: win32more.Windows.Win32.Graphics.Dxgi.IDXGIAdapter, DriverType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DRIVER_TYPE, Software: win32more.Windows.Win32.Foundation.HMODULE, Flags: UInt32, SDKVersion: UInt32, pSwapChainDesc: POINTER(win32more.Windows.Win32.Graphics.Dxgi.DXGI_SWAP_CHAIN_DESC), ppSwapChain: POINTER(win32more.Windows.Win32.Graphics.Dxgi.IDXGISwapChain), ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10CreateBlob(NumBytes: UIntPtr, ppBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10CompileShader(pSrcData: win32more.Windows.Win32.Foundation.PSTR, SrcDataSize: UIntPtr, pFileName: win32more.Windows.Win32.Foundation.PSTR, pDefines: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_MACRO), pInclude: win32more.Windows.Win32.Graphics.Direct3D.ID3DInclude, pFunctionName: win32more.Windows.Win32.Foundation.PSTR, pProfile: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, ppShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob), ppErrorMsgs: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10DisassembleShader(pShader: VoidPtr, BytecodeLength: UIntPtr, EnableColorCode: win32more.Windows.Win32.Foundation.BOOL, pComments: win32more.Windows.Win32.Foundation.PSTR, ppDisassembly: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10GetPixelShaderProfile(pDevice: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('d3d10.dll')
def D3D10GetVertexShaderProfile(pDevice: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('d3d10.dll')
def D3D10GetGeometryShaderProfile(pDevice: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('d3d10.dll')
def D3D10ReflectShader(pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, ppReflector: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderReflection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10PreprocessShader(pSrcData: win32more.Windows.Win32.Foundation.PSTR, SrcDataSize: UIntPtr, pFileName: win32more.Windows.Win32.Foundation.PSTR, pDefines: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_MACRO), pInclude: win32more.Windows.Win32.Graphics.Direct3D.ID3DInclude, ppShaderText: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob), ppErrorMsgs: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10GetInputSignatureBlob(pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, ppSignatureBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10GetOutputSignatureBlob(pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, ppSignatureBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10GetInputAndOutputSignatureBlob(pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, ppSignatureBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10GetShaderDebugInfo(pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, ppDebugInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10StateBlockMaskUnion(pA: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK), pB: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK), pResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10StateBlockMaskIntersect(pA: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK), pB: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK), pResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10StateBlockMaskDifference(pA: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK), pB: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK), pResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10StateBlockMaskEnableCapture(pMask: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK), StateType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES, RangeStart: UInt32, RangeLength: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10StateBlockMaskDisableCapture(pMask: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK), StateType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES, RangeStart: UInt32, RangeLength: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10StateBlockMaskEnableAll(pMask: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10StateBlockMaskDisableAll(pMask: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10StateBlockMaskGetSetting(pMask: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK), StateType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES, Entry: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('d3d10.dll')
def D3D10CreateStateBlock(pDevice: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device, pStateBlockMask: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK), ppStateBlock: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10StateBlock)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10CompileEffectFromMemory(pData: VoidPtr, DataLength: UIntPtr, pSrcFileName: win32more.Windows.Win32.Foundation.PSTR, pDefines: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_MACRO), pInclude: win32more.Windows.Win32.Graphics.Direct3D.ID3DInclude, HLSLFlags: UInt32, FXFlags: UInt32, ppCompiledEffect: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob), ppErrors: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10CreateEffectFromMemory(pData: VoidPtr, DataLength: UIntPtr, FXFlags: UInt32, pDevice: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device, pEffectPool: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectPool, ppEffect: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Effect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10CreateEffectPoolFromMemory(pData: VoidPtr, DataLength: UIntPtr, FXFlags: UInt32, pDevice: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device, ppEffectPool: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectPool)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10.dll')
def D3D10DisassembleEffect(pEffect: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Effect, EnableColorCode: win32more.Windows.Win32.Foundation.BOOL, ppDisassembly: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10_1.dll')
def D3D10CreateDevice1(pAdapter: win32more.Windows.Win32.Graphics.Dxgi.IDXGIAdapter, DriverType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DRIVER_TYPE, Software: win32more.Windows.Win32.Foundation.HMODULE, Flags: UInt32, HardwareLevel: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FEATURE_LEVEL1, SDKVersion: UInt32, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d10_1.dll')
def D3D10CreateDeviceAndSwapChain1(pAdapter: win32more.Windows.Win32.Graphics.Dxgi.IDXGIAdapter, DriverType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DRIVER_TYPE, Software: win32more.Windows.Win32.Foundation.HMODULE, Flags: UInt32, HardwareLevel: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FEATURE_LEVEL1, SDKVersion: UInt32, pSwapChainDesc: POINTER(win32more.Windows.Win32.Graphics.Dxgi.DXGI_SWAP_CHAIN_DESC), ppSwapChain: POINTER(win32more.Windows.Win32.Graphics.Dxgi.IDXGISwapChain), ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
D3D10_ASYNC_GETDATA_FLAG = Int32
D3D10_ASYNC_GETDATA_DONOTFLUSH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_ASYNC_GETDATA_FLAG = 1
D3D10_BIND_FLAG = Int32
D3D10_BIND_VERTEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BIND_FLAG = 1
D3D10_BIND_INDEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BIND_FLAG = 2
D3D10_BIND_CONSTANT_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BIND_FLAG = 4
D3D10_BIND_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BIND_FLAG = 8
D3D10_BIND_STREAM_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BIND_FLAG = 16
D3D10_BIND_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BIND_FLAG = 32
D3D10_BIND_DEPTH_STENCIL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BIND_FLAG = 64
D3D10_BLEND = Int32
D3D10_BLEND_ZERO: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 1
D3D10_BLEND_ONE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 2
D3D10_BLEND_SRC_COLOR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 3
D3D10_BLEND_INV_SRC_COLOR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 4
D3D10_BLEND_SRC_ALPHA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 5
D3D10_BLEND_INV_SRC_ALPHA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 6
D3D10_BLEND_DEST_ALPHA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 7
D3D10_BLEND_INV_DEST_ALPHA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 8
D3D10_BLEND_DEST_COLOR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 9
D3D10_BLEND_INV_DEST_COLOR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 10
D3D10_BLEND_SRC_ALPHA_SAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 11
D3D10_BLEND_BLEND_FACTOR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 14
D3D10_BLEND_INV_BLEND_FACTOR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 15
D3D10_BLEND_SRC1_COLOR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 16
D3D10_BLEND_INV_SRC1_COLOR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 17
D3D10_BLEND_SRC1_ALPHA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 18
D3D10_BLEND_INV_SRC1_ALPHA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND = 19
class D3D10_BLEND_DESC(Structure):
    AlphaToCoverageEnable: win32more.Windows.Win32.Foundation.BOOL
    BlendEnable: win32more.Windows.Win32.Foundation.BOOL * 8
    SrcBlend: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND
    DestBlend: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND
    BlendOp: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_OP
    SrcBlendAlpha: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND
    DestBlendAlpha: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND
    BlendOpAlpha: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_OP
    RenderTargetWriteMask: Byte * 8
class D3D10_BLEND_DESC1(Structure):
    AlphaToCoverageEnable: win32more.Windows.Win32.Foundation.BOOL
    IndependentBlendEnable: win32more.Windows.Win32.Foundation.BOOL
    RenderTarget: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RENDER_TARGET_BLEND_DESC1 * 8
D3D10_BLEND_OP = Int32
D3D10_BLEND_OP_ADD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_OP = 1
D3D10_BLEND_OP_SUBTRACT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_OP = 2
D3D10_BLEND_OP_REV_SUBTRACT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_OP = 3
D3D10_BLEND_OP_MIN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_OP = 4
D3D10_BLEND_OP_MAX: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_OP = 5
class D3D10_BOX(Structure):
    left: UInt32
    top: UInt32
    front: UInt32
    right: UInt32
    bottom: UInt32
    back: UInt32
class D3D10_BUFFER_DESC(Structure):
    ByteWidth: UInt32
    Usage: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_USAGE
    BindFlags: UInt32
    CPUAccessFlags: UInt32
    MiscFlags: UInt32
class D3D10_BUFFER_RTV(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        FirstElement: UInt32
        ElementOffset: UInt32
    class _Anonymous2_e__Union(Union):
        NumElements: UInt32
        ElementWidth: UInt32
class D3D10_BUFFER_SRV(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        FirstElement: UInt32
        ElementOffset: UInt32
    class _Anonymous2_e__Union(Union):
        NumElements: UInt32
        ElementWidth: UInt32
D3D10_CLEAR_FLAG = Int32
D3D10_CLEAR_DEPTH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CLEAR_FLAG = 1
D3D10_CLEAR_STENCIL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CLEAR_FLAG = 2
D3D10_COLOR_WRITE_ENABLE = Int32
D3D10_COLOR_WRITE_ENABLE_RED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COLOR_WRITE_ENABLE = 1
D3D10_COLOR_WRITE_ENABLE_GREEN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COLOR_WRITE_ENABLE = 2
D3D10_COLOR_WRITE_ENABLE_BLUE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COLOR_WRITE_ENABLE = 4
D3D10_COLOR_WRITE_ENABLE_ALPHA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COLOR_WRITE_ENABLE = 8
D3D10_COLOR_WRITE_ENABLE_ALL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COLOR_WRITE_ENABLE = 15
D3D10_COMPARISON_FUNC = Int32
D3D10_COMPARISON_NEVER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COMPARISON_FUNC = 1
D3D10_COMPARISON_LESS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COMPARISON_FUNC = 2
D3D10_COMPARISON_EQUAL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COMPARISON_FUNC = 3
D3D10_COMPARISON_LESS_EQUAL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COMPARISON_FUNC = 4
D3D10_COMPARISON_GREATER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COMPARISON_FUNC = 5
D3D10_COMPARISON_NOT_EQUAL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COMPARISON_FUNC = 6
D3D10_COMPARISON_GREATER_EQUAL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COMPARISON_FUNC = 7
D3D10_COMPARISON_ALWAYS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COMPARISON_FUNC = 8
D3D10_COUNTER = Int32
D3D10_COUNTER_GPU_IDLE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 0
D3D10_COUNTER_VERTEX_PROCESSING: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 1
D3D10_COUNTER_GEOMETRY_PROCESSING: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 2
D3D10_COUNTER_PIXEL_PROCESSING: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 3
D3D10_COUNTER_OTHER_GPU_PROCESSING: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 4
D3D10_COUNTER_HOST_ADAPTER_BANDWIDTH_UTILIZATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 5
D3D10_COUNTER_LOCAL_VIDMEM_BANDWIDTH_UTILIZATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 6
D3D10_COUNTER_VERTEX_THROUGHPUT_UTILIZATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 7
D3D10_COUNTER_TRIANGLE_SETUP_THROUGHPUT_UTILIZATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 8
D3D10_COUNTER_FILLRATE_THROUGHPUT_UTILIZATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 9
D3D10_COUNTER_VS_MEMORY_LIMITED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 10
D3D10_COUNTER_VS_COMPUTATION_LIMITED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 11
D3D10_COUNTER_GS_MEMORY_LIMITED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 12
D3D10_COUNTER_GS_COMPUTATION_LIMITED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 13
D3D10_COUNTER_PS_MEMORY_LIMITED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 14
D3D10_COUNTER_PS_COMPUTATION_LIMITED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 15
D3D10_COUNTER_POST_TRANSFORM_CACHE_HIT_RATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 16
D3D10_COUNTER_TEXTURE_CACHE_HIT_RATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 17
D3D10_COUNTER_DEVICE_DEPENDENT_0: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER = 1073741824
class D3D10_COUNTER_DESC(Structure):
    Counter: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER
    MiscFlags: UInt32
class D3D10_COUNTER_INFO(Structure):
    LastDeviceDependentCounter: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER
    NumSimultaneousCounters: UInt32
    NumDetectableParallelUnits: Byte
D3D10_COUNTER_TYPE = Int32
D3D10_COUNTER_TYPE_FLOAT32: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER_TYPE = 0
D3D10_COUNTER_TYPE_UINT16: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER_TYPE = 1
D3D10_COUNTER_TYPE_UINT32: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER_TYPE = 2
D3D10_COUNTER_TYPE_UINT64: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER_TYPE = 3
D3D10_CPU_ACCESS_FLAG = Int32
D3D10_CPU_ACCESS_WRITE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CPU_ACCESS_FLAG = 65536
D3D10_CPU_ACCESS_READ: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CPU_ACCESS_FLAG = 131072
D3D10_CREATE_DEVICE_FLAG = Int32
D3D10_CREATE_DEVICE_SINGLETHREADED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CREATE_DEVICE_FLAG = 1
D3D10_CREATE_DEVICE_DEBUG: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CREATE_DEVICE_FLAG = 2
D3D10_CREATE_DEVICE_SWITCH_TO_REF: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CREATE_DEVICE_FLAG = 4
D3D10_CREATE_DEVICE_PREVENT_INTERNAL_THREADING_OPTIMIZATIONS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CREATE_DEVICE_FLAG = 8
D3D10_CREATE_DEVICE_ALLOW_NULL_FROM_MAP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CREATE_DEVICE_FLAG = 16
D3D10_CREATE_DEVICE_BGRA_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CREATE_DEVICE_FLAG = 32
D3D10_CREATE_DEVICE_PREVENT_ALTERING_LAYER_SETTINGS_FROM_REGISTRY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CREATE_DEVICE_FLAG = 128
D3D10_CREATE_DEVICE_STRICT_VALIDATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CREATE_DEVICE_FLAG = 512
D3D10_CREATE_DEVICE_DEBUGGABLE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CREATE_DEVICE_FLAG = 1024
D3D10_CULL_MODE = Int32
D3D10_CULL_NONE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CULL_MODE = 1
D3D10_CULL_FRONT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CULL_MODE = 2
D3D10_CULL_BACK: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CULL_MODE = 3
class D3D10_DEPTH_STENCILOP_DESC(Structure):
    StencilFailOp: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STENCIL_OP
    StencilDepthFailOp: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STENCIL_OP
    StencilPassOp: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STENCIL_OP
    StencilFunc: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COMPARISON_FUNC
class D3D10_DEPTH_STENCIL_DESC(Structure):
    DepthEnable: win32more.Windows.Win32.Foundation.BOOL
    DepthWriteMask: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEPTH_WRITE_MASK
    DepthFunc: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COMPARISON_FUNC
    StencilEnable: win32more.Windows.Win32.Foundation.BOOL
    StencilReadMask: Byte
    StencilWriteMask: Byte
    FrontFace: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEPTH_STENCILOP_DESC
    BackFace: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEPTH_STENCILOP_DESC
class D3D10_DEPTH_STENCIL_VIEW_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DSV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX1D_DSV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX1D_ARRAY_DSV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2D_DSV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2D_ARRAY_DSV
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2DMS_DSV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2DMS_ARRAY_DSV
D3D10_DEPTH_WRITE_MASK = Int32
D3D10_DEPTH_WRITE_MASK_ZERO: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEPTH_WRITE_MASK = 0
D3D10_DEPTH_WRITE_MASK_ALL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEPTH_WRITE_MASK = 1
D3D10_DEVICE_STATE_TYPES = Int32
D3D10_DST_SO_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 1
D3D10_DST_OM_RENDER_TARGETS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 2
D3D10_DST_OM_DEPTH_STENCIL_STATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 3
D3D10_DST_OM_BLEND_STATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 4
D3D10_DST_VS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 5
D3D10_DST_VS_SAMPLERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 6
D3D10_DST_VS_SHADER_RESOURCES: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 7
D3D10_DST_VS_CONSTANT_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 8
D3D10_DST_GS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 9
D3D10_DST_GS_SAMPLERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 10
D3D10_DST_GS_SHADER_RESOURCES: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 11
D3D10_DST_GS_CONSTANT_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 12
D3D10_DST_PS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 13
D3D10_DST_PS_SAMPLERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 14
D3D10_DST_PS_SHADER_RESOURCES: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 15
D3D10_DST_PS_CONSTANT_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 16
D3D10_DST_IA_VERTEX_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 17
D3D10_DST_IA_INDEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 18
D3D10_DST_IA_INPUT_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 19
D3D10_DST_IA_PRIMITIVE_TOPOLOGY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 20
D3D10_DST_RS_VIEWPORTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 21
D3D10_DST_RS_SCISSOR_RECTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 22
D3D10_DST_RS_RASTERIZER_STATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 23
D3D10_DST_PREDICATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEVICE_STATE_TYPES = 24
D3D10_DRIVER_TYPE = Int32
D3D10_DRIVER_TYPE_HARDWARE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DRIVER_TYPE = 0
D3D10_DRIVER_TYPE_REFERENCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DRIVER_TYPE = 1
D3D10_DRIVER_TYPE_NULL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DRIVER_TYPE = 2
D3D10_DRIVER_TYPE_SOFTWARE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DRIVER_TYPE = 3
D3D10_DRIVER_TYPE_WARP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DRIVER_TYPE = 5
D3D10_DSV_DIMENSION = Int32
D3D10_DSV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DSV_DIMENSION = 0
D3D10_DSV_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DSV_DIMENSION = 1
D3D10_DSV_DIMENSION_TEXTURE1DARRAY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DSV_DIMENSION = 2
D3D10_DSV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DSV_DIMENSION = 3
D3D10_DSV_DIMENSION_TEXTURE2DARRAY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DSV_DIMENSION = 4
D3D10_DSV_DIMENSION_TEXTURE2DMS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DSV_DIMENSION = 5
D3D10_DSV_DIMENSION_TEXTURE2DMSARRAY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DSV_DIMENSION = 6
class D3D10_EFFECT_DESC(Structure):
    IsChildEffect: win32more.Windows.Win32.Foundation.BOOL
    ConstantBuffers: UInt32
    SharedConstantBuffers: UInt32
    GlobalVariables: UInt32
    SharedGlobalVariables: UInt32
    Techniques: UInt32
class D3D10_EFFECT_SHADER_DESC(Structure):
    pInputSignature: POINTER(Byte)
    IsInline: win32more.Windows.Win32.Foundation.BOOL
    pBytecode: POINTER(Byte)
    BytecodeLength: UInt32
    SODecl: win32more.Windows.Win32.Foundation.PSTR
    NumInputSignatureEntries: UInt32
    NumOutputSignatureEntries: UInt32
class D3D10_EFFECT_TYPE_DESC(Structure):
    TypeName: win32more.Windows.Win32.Foundation.PSTR
    Class: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_CLASS
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_TYPE
    Elements: UInt32
    Members: UInt32
    Rows: UInt32
    Columns: UInt32
    PackedSize: UInt32
    UnpackedSize: UInt32
    Stride: UInt32
class D3D10_EFFECT_VARIABLE_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    Semantic: win32more.Windows.Win32.Foundation.PSTR
    Flags: UInt32
    Annotations: UInt32
    BufferOffset: UInt32
    ExplicitBindPoint: UInt32
D3D10_FEATURE_LEVEL1 = Int32
D3D10_FEATURE_LEVEL_10_0: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FEATURE_LEVEL1 = 40960
D3D10_FEATURE_LEVEL_10_1: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FEATURE_LEVEL1 = 41216
D3D10_FEATURE_LEVEL_9_1: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FEATURE_LEVEL1 = 37120
D3D10_FEATURE_LEVEL_9_2: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FEATURE_LEVEL1 = 37376
D3D10_FEATURE_LEVEL_9_3: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FEATURE_LEVEL1 = 37632
D3D10_FILL_MODE = Int32
D3D10_FILL_WIREFRAME: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILL_MODE = 2
D3D10_FILL_SOLID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILL_MODE = 3
D3D10_FILTER = Int32
D3D10_FILTER_MIN_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 0
D3D10_FILTER_MIN_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 1
D3D10_FILTER_MIN_POINT_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 4
D3D10_FILTER_MIN_POINT_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 5
D3D10_FILTER_MIN_LINEAR_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 16
D3D10_FILTER_MIN_LINEAR_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 17
D3D10_FILTER_MIN_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 20
D3D10_FILTER_MIN_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 21
D3D10_FILTER_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 85
D3D10_FILTER_COMPARISON_MIN_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 128
D3D10_FILTER_COMPARISON_MIN_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 129
D3D10_FILTER_COMPARISON_MIN_POINT_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 132
D3D10_FILTER_COMPARISON_MIN_POINT_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 133
D3D10_FILTER_COMPARISON_MIN_LINEAR_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 144
D3D10_FILTER_COMPARISON_MIN_LINEAR_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 145
D3D10_FILTER_COMPARISON_MIN_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 148
D3D10_FILTER_COMPARISON_MIN_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 149
D3D10_FILTER_COMPARISON_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = 213
D3D10_FILTER_TEXT_1BIT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER = -2147483648
D3D10_FILTER_TYPE = Int32
D3D10_FILTER_TYPE_POINT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER_TYPE = 0
D3D10_FILTER_TYPE_LINEAR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER_TYPE = 1
D3D10_FORMAT_SUPPORT = Int32
D3D10_FORMAT_SUPPORT_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 1
D3D10_FORMAT_SUPPORT_IA_VERTEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 2
D3D10_FORMAT_SUPPORT_IA_INDEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 4
D3D10_FORMAT_SUPPORT_SO_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 8
D3D10_FORMAT_SUPPORT_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 16
D3D10_FORMAT_SUPPORT_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 32
D3D10_FORMAT_SUPPORT_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 64
D3D10_FORMAT_SUPPORT_TEXTURECUBE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 128
D3D10_FORMAT_SUPPORT_SHADER_LOAD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 256
D3D10_FORMAT_SUPPORT_SHADER_SAMPLE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 512
D3D10_FORMAT_SUPPORT_SHADER_SAMPLE_COMPARISON: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 1024
D3D10_FORMAT_SUPPORT_SHADER_SAMPLE_MONO_TEXT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 2048
D3D10_FORMAT_SUPPORT_MIP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 4096
D3D10_FORMAT_SUPPORT_MIP_AUTOGEN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 8192
D3D10_FORMAT_SUPPORT_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 16384
D3D10_FORMAT_SUPPORT_BLENDABLE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 32768
D3D10_FORMAT_SUPPORT_DEPTH_STENCIL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 65536
D3D10_FORMAT_SUPPORT_CPU_LOCKABLE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 131072
D3D10_FORMAT_SUPPORT_MULTISAMPLE_RESOLVE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 262144
D3D10_FORMAT_SUPPORT_DISPLAY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 524288
D3D10_FORMAT_SUPPORT_CAST_WITHIN_BIT_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 1048576
D3D10_FORMAT_SUPPORT_MULTISAMPLE_RENDERTARGET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 2097152
D3D10_FORMAT_SUPPORT_MULTISAMPLE_LOAD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 4194304
D3D10_FORMAT_SUPPORT_SHADER_GATHER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 8388608
D3D10_FORMAT_SUPPORT_BACK_BUFFER_CAST: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FORMAT_SUPPORT = 16777216
class D3D10_INFO_QUEUE_FILTER(Structure):
    AllowList: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INFO_QUEUE_FILTER_DESC
    DenyList: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INFO_QUEUE_FILTER_DESC
class D3D10_INFO_QUEUE_FILTER_DESC(Structure):
    NumCategories: UInt32
    pCategoryList: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY)
    NumSeverities: UInt32
    pSeverityList: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_SEVERITY)
    NumIDs: UInt32
    pIDList: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID)
D3D10_INPUT_CLASSIFICATION = Int32
D3D10_INPUT_PER_VERTEX_DATA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INPUT_CLASSIFICATION = 0
D3D10_INPUT_PER_INSTANCE_DATA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INPUT_CLASSIFICATION = 1
class D3D10_INPUT_ELEMENT_DESC(Structure):
    SemanticName: win32more.Windows.Win32.Foundation.PSTR
    SemanticIndex: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    InputSlot: UInt32
    AlignedByteOffset: UInt32
    InputSlotClass: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INPUT_CLASSIFICATION
    InstanceDataStepRate: UInt32
D3D10_MAP = Int32
D3D10_MAP_READ: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAP = 1
D3D10_MAP_WRITE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAP = 2
D3D10_MAP_READ_WRITE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAP = 3
D3D10_MAP_WRITE_DISCARD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAP = 4
D3D10_MAP_WRITE_NO_OVERWRITE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAP = 5
class D3D10_MAPPED_TEXTURE2D(Structure):
    pData: VoidPtr
    RowPitch: UInt32
class D3D10_MAPPED_TEXTURE3D(Structure):
    pData: VoidPtr
    RowPitch: UInt32
    DepthPitch: UInt32
D3D10_MAP_FLAG = Int32
D3D10_MAP_FLAG_DO_NOT_WAIT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAP_FLAG = 1048576
class D3D10_MESSAGE(Structure):
    Category: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY
    Severity: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_SEVERITY
    ID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID
    pDescription: POINTER(Byte)
    DescriptionByteLength: UIntPtr
D3D10_MESSAGE_CATEGORY = Int32
D3D10_MESSAGE_CATEGORY_APPLICATION_DEFINED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY = 0
D3D10_MESSAGE_CATEGORY_MISCELLANEOUS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY = 1
D3D10_MESSAGE_CATEGORY_INITIALIZATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY = 2
D3D10_MESSAGE_CATEGORY_CLEANUP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY = 3
D3D10_MESSAGE_CATEGORY_COMPILATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY = 4
D3D10_MESSAGE_CATEGORY_STATE_CREATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY = 5
D3D10_MESSAGE_CATEGORY_STATE_SETTING: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY = 6
D3D10_MESSAGE_CATEGORY_STATE_GETTING: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY = 7
D3D10_MESSAGE_CATEGORY_RESOURCE_MANIPULATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY = 8
D3D10_MESSAGE_CATEGORY_EXECUTION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY = 9
D3D10_MESSAGE_CATEGORY_SHADER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY = 10
D3D10_MESSAGE_ID = Int32
D3D10_MESSAGE_ID_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 0
D3D10_MESSAGE_ID_DEVICE_IASETVERTEXBUFFERS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1
D3D10_MESSAGE_ID_DEVICE_IASETINDEXBUFFER_HAZARD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 2
D3D10_MESSAGE_ID_DEVICE_VSSETSHADERRESOURCES_HAZARD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 3
D3D10_MESSAGE_ID_DEVICE_VSSETCONSTANTBUFFERS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 4
D3D10_MESSAGE_ID_DEVICE_GSSETSHADERRESOURCES_HAZARD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 5
D3D10_MESSAGE_ID_DEVICE_GSSETCONSTANTBUFFERS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 6
D3D10_MESSAGE_ID_DEVICE_PSSETSHADERRESOURCES_HAZARD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 7
D3D10_MESSAGE_ID_DEVICE_PSSETCONSTANTBUFFERS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 8
D3D10_MESSAGE_ID_DEVICE_OMSETRENDERTARGETS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 9
D3D10_MESSAGE_ID_DEVICE_SOSETTARGETS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 10
D3D10_MESSAGE_ID_STRING_FROM_APPLICATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 11
D3D10_MESSAGE_ID_CORRUPTED_THIS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 12
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER1: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 13
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER2: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 14
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER3: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 15
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER4: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 16
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER5: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 17
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER6: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 18
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER7: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 19
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER8: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 20
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER9: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 21
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER10: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 22
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER11: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 23
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER12: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 24
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER13: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 25
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER14: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 26
D3D10_MESSAGE_ID_CORRUPTED_PARAMETER15: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 27
D3D10_MESSAGE_ID_CORRUPTED_MULTITHREADING: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 28
D3D10_MESSAGE_ID_MESSAGE_REPORTING_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 29
D3D10_MESSAGE_ID_IASETINPUTLAYOUT_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 30
D3D10_MESSAGE_ID_IASETVERTEXBUFFERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 31
D3D10_MESSAGE_ID_IASETINDEXBUFFER_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 32
D3D10_MESSAGE_ID_VSSETSHADER_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 33
D3D10_MESSAGE_ID_VSSETSHADERRESOURCES_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 34
D3D10_MESSAGE_ID_VSSETCONSTANTBUFFERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 35
D3D10_MESSAGE_ID_VSSETSAMPLERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 36
D3D10_MESSAGE_ID_GSSETSHADER_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 37
D3D10_MESSAGE_ID_GSSETSHADERRESOURCES_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 38
D3D10_MESSAGE_ID_GSSETCONSTANTBUFFERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 39
D3D10_MESSAGE_ID_GSSETSAMPLERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 40
D3D10_MESSAGE_ID_SOSETTARGETS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 41
D3D10_MESSAGE_ID_PSSETSHADER_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 42
D3D10_MESSAGE_ID_PSSETSHADERRESOURCES_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 43
D3D10_MESSAGE_ID_PSSETCONSTANTBUFFERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 44
D3D10_MESSAGE_ID_PSSETSAMPLERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 45
D3D10_MESSAGE_ID_RSSETSTATE_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 46
D3D10_MESSAGE_ID_OMSETBLENDSTATE_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 47
D3D10_MESSAGE_ID_OMSETDEPTHSTENCILSTATE_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 48
D3D10_MESSAGE_ID_OMSETRENDERTARGETS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 49
D3D10_MESSAGE_ID_SETPREDICATION_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 50
D3D10_MESSAGE_ID_GETPRIVATEDATA_MOREDATA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 51
D3D10_MESSAGE_ID_SETPRIVATEDATA_INVALIDFREEDATA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 52
D3D10_MESSAGE_ID_SETPRIVATEDATA_INVALIDIUNKNOWN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 53
D3D10_MESSAGE_ID_SETPRIVATEDATA_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 54
D3D10_MESSAGE_ID_SETPRIVATEDATA_CHANGINGPARAMS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 55
D3D10_MESSAGE_ID_SETPRIVATEDATA_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 56
D3D10_MESSAGE_ID_CREATEBUFFER_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 57
D3D10_MESSAGE_ID_CREATEBUFFER_INVALIDSAMPLES: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 58
D3D10_MESSAGE_ID_CREATEBUFFER_UNRECOGNIZEDUSAGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 59
D3D10_MESSAGE_ID_CREATEBUFFER_UNRECOGNIZEDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 60
D3D10_MESSAGE_ID_CREATEBUFFER_UNRECOGNIZEDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 61
D3D10_MESSAGE_ID_CREATEBUFFER_UNRECOGNIZEDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 62
D3D10_MESSAGE_ID_CREATEBUFFER_INVALIDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 63
D3D10_MESSAGE_ID_CREATEBUFFER_INVALIDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 64
D3D10_MESSAGE_ID_CREATEBUFFER_INVALIDINITIALDATA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 65
D3D10_MESSAGE_ID_CREATEBUFFER_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 66
D3D10_MESSAGE_ID_CREATEBUFFER_INVALIDMIPLEVELS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 67
D3D10_MESSAGE_ID_CREATEBUFFER_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 68
D3D10_MESSAGE_ID_CREATEBUFFER_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 69
D3D10_MESSAGE_ID_CREATEBUFFER_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 70
D3D10_MESSAGE_ID_CREATEBUFFER_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 71
D3D10_MESSAGE_ID_CREATEBUFFER_INVALIDCONSTANTBUFFERBINDINGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 72
D3D10_MESSAGE_ID_CREATEBUFFER_LARGEALLOCATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 73
D3D10_MESSAGE_ID_CREATETEXTURE1D_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 74
D3D10_MESSAGE_ID_CREATETEXTURE1D_UNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 75
D3D10_MESSAGE_ID_CREATETEXTURE1D_INVALIDSAMPLES: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 76
D3D10_MESSAGE_ID_CREATETEXTURE1D_UNRECOGNIZEDUSAGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 77
D3D10_MESSAGE_ID_CREATETEXTURE1D_UNRECOGNIZEDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 78
D3D10_MESSAGE_ID_CREATETEXTURE1D_UNRECOGNIZEDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 79
D3D10_MESSAGE_ID_CREATETEXTURE1D_UNRECOGNIZEDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 80
D3D10_MESSAGE_ID_CREATETEXTURE1D_INVALIDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 81
D3D10_MESSAGE_ID_CREATETEXTURE1D_INVALIDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 82
D3D10_MESSAGE_ID_CREATETEXTURE1D_INVALIDINITIALDATA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 83
D3D10_MESSAGE_ID_CREATETEXTURE1D_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 84
D3D10_MESSAGE_ID_CREATETEXTURE1D_INVALIDMIPLEVELS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 85
D3D10_MESSAGE_ID_CREATETEXTURE1D_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 86
D3D10_MESSAGE_ID_CREATETEXTURE1D_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 87
D3D10_MESSAGE_ID_CREATETEXTURE1D_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 88
D3D10_MESSAGE_ID_CREATETEXTURE1D_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 89
D3D10_MESSAGE_ID_CREATETEXTURE1D_LARGEALLOCATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 90
D3D10_MESSAGE_ID_CREATETEXTURE2D_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 91
D3D10_MESSAGE_ID_CREATETEXTURE2D_UNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 92
D3D10_MESSAGE_ID_CREATETEXTURE2D_INVALIDSAMPLES: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 93
D3D10_MESSAGE_ID_CREATETEXTURE2D_UNRECOGNIZEDUSAGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 94
D3D10_MESSAGE_ID_CREATETEXTURE2D_UNRECOGNIZEDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 95
D3D10_MESSAGE_ID_CREATETEXTURE2D_UNRECOGNIZEDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 96
D3D10_MESSAGE_ID_CREATETEXTURE2D_UNRECOGNIZEDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 97
D3D10_MESSAGE_ID_CREATETEXTURE2D_INVALIDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 98
D3D10_MESSAGE_ID_CREATETEXTURE2D_INVALIDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 99
D3D10_MESSAGE_ID_CREATETEXTURE2D_INVALIDINITIALDATA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 100
D3D10_MESSAGE_ID_CREATETEXTURE2D_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 101
D3D10_MESSAGE_ID_CREATETEXTURE2D_INVALIDMIPLEVELS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 102
D3D10_MESSAGE_ID_CREATETEXTURE2D_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 103
D3D10_MESSAGE_ID_CREATETEXTURE2D_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 104
D3D10_MESSAGE_ID_CREATETEXTURE2D_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 105
D3D10_MESSAGE_ID_CREATETEXTURE2D_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 106
D3D10_MESSAGE_ID_CREATETEXTURE2D_LARGEALLOCATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 107
D3D10_MESSAGE_ID_CREATETEXTURE3D_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 108
D3D10_MESSAGE_ID_CREATETEXTURE3D_UNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 109
D3D10_MESSAGE_ID_CREATETEXTURE3D_INVALIDSAMPLES: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 110
D3D10_MESSAGE_ID_CREATETEXTURE3D_UNRECOGNIZEDUSAGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 111
D3D10_MESSAGE_ID_CREATETEXTURE3D_UNRECOGNIZEDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 112
D3D10_MESSAGE_ID_CREATETEXTURE3D_UNRECOGNIZEDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 113
D3D10_MESSAGE_ID_CREATETEXTURE3D_UNRECOGNIZEDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 114
D3D10_MESSAGE_ID_CREATETEXTURE3D_INVALIDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 115
D3D10_MESSAGE_ID_CREATETEXTURE3D_INVALIDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 116
D3D10_MESSAGE_ID_CREATETEXTURE3D_INVALIDINITIALDATA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 117
D3D10_MESSAGE_ID_CREATETEXTURE3D_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 118
D3D10_MESSAGE_ID_CREATETEXTURE3D_INVALIDMIPLEVELS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 119
D3D10_MESSAGE_ID_CREATETEXTURE3D_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 120
D3D10_MESSAGE_ID_CREATETEXTURE3D_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 121
D3D10_MESSAGE_ID_CREATETEXTURE3D_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 122
D3D10_MESSAGE_ID_CREATETEXTURE3D_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 123
D3D10_MESSAGE_ID_CREATETEXTURE3D_LARGEALLOCATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 124
D3D10_MESSAGE_ID_CREATESHADERRESOURCEVIEW_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 125
D3D10_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 126
D3D10_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 127
D3D10_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 128
D3D10_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 129
D3D10_MESSAGE_ID_CREATESHADERRESOURCEVIEW_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 130
D3D10_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 131
D3D10_MESSAGE_ID_CREATESHADERRESOURCEVIEW_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 132
D3D10_MESSAGE_ID_CREATERENDERTARGETVIEW_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 133
D3D10_MESSAGE_ID_CREATERENDERTARGETVIEW_UNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 134
D3D10_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 135
D3D10_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 136
D3D10_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 137
D3D10_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 138
D3D10_MESSAGE_ID_CREATERENDERTARGETVIEW_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 139
D3D10_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 140
D3D10_MESSAGE_ID_CREATERENDERTARGETVIEW_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 141
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 142
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 143
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 144
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 145
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 146
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 147
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 148
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 149
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 150
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_TOOMANYELEMENTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 151
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 152
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_INCOMPATIBLEFORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 153
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDSLOT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 154
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDINPUTSLOTCLASS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 155
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_STEPRATESLOTCLASSMISMATCH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 156
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDSLOTCLASSCHANGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 157
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDSTEPRATECHANGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 158
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDALIGNMENT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 159
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_DUPLICATESEMANTIC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 160
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_UNPARSEABLEINPUTSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 161
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_NULLSEMANTIC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 162
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_MISSINGELEMENT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 163
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 164
D3D10_MESSAGE_ID_CREATEVERTEXSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 165
D3D10_MESSAGE_ID_CREATEVERTEXSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 166
D3D10_MESSAGE_ID_CREATEVERTEXSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 167
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 168
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 169
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 170
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 171
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 172
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 173
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDNUMENTRIES: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 174
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_OUTPUTSTREAMSTRIDEUNUSED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 175
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_UNEXPECTEDDECL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 176
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_EXPECTEDDECL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 177
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_OUTPUTSLOT0EXPECTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 178
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDOUTPUTSLOT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 179
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_ONLYONEELEMENTPERSLOT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 180
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDCOMPONENTCOUNT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 181
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSTARTCOMPONENTANDCOMPONENTCOUNT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 182
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDGAPDEFINITION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 183
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_REPEATEDOUTPUT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 184
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDOUTPUTSTREAMSTRIDE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 185
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_MISSINGSEMANTIC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 186
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_MASKMISMATCH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 187
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_CANTHAVEONLYGAPS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 188
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_DECLTOOCOMPLEX: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 189
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_MISSINGOUTPUTSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 190
D3D10_MESSAGE_ID_CREATEPIXELSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 191
D3D10_MESSAGE_ID_CREATEPIXELSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 192
D3D10_MESSAGE_ID_CREATEPIXELSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 193
D3D10_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDFILLMODE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 194
D3D10_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDCULLMODE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 195
D3D10_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDDEPTHBIASCLAMP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 196
D3D10_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDSLOPESCALEDDEPTHBIAS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 197
D3D10_MESSAGE_ID_CREATERASTERIZERSTATE_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 198
D3D10_MESSAGE_ID_CREATERASTERIZERSTATE_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 199
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDDEPTHWRITEMASK: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 200
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDDEPTHFUNC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 201
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILFAILOP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 202
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILZFAILOP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 203
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILPASSOP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 204
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILFUNC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 205
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILFAILOP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 206
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILZFAILOP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 207
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILPASSOP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 208
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILFUNC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 209
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 210
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 211
D3D10_MESSAGE_ID_CREATEBLENDSTATE_INVALIDSRCBLEND: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 212
D3D10_MESSAGE_ID_CREATEBLENDSTATE_INVALIDDESTBLEND: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 213
D3D10_MESSAGE_ID_CREATEBLENDSTATE_INVALIDBLENDOP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 214
D3D10_MESSAGE_ID_CREATEBLENDSTATE_INVALIDSRCBLENDALPHA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 215
D3D10_MESSAGE_ID_CREATEBLENDSTATE_INVALIDDESTBLENDALPHA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 216
D3D10_MESSAGE_ID_CREATEBLENDSTATE_INVALIDBLENDOPALPHA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 217
D3D10_MESSAGE_ID_CREATEBLENDSTATE_INVALIDRENDERTARGETWRITEMASK: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 218
D3D10_MESSAGE_ID_CREATEBLENDSTATE_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 219
D3D10_MESSAGE_ID_CREATEBLENDSTATE_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 220
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDFILTER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 221
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDADDRESSU: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 222
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDADDRESSV: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 223
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDADDRESSW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 224
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDMIPLODBIAS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 225
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDMAXANISOTROPY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 226
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDCOMPARISONFUNC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 227
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDMINLOD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 228
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDMAXLOD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 229
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 230
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 231
D3D10_MESSAGE_ID_CREATEQUERYORPREDICATE_INVALIDQUERY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 232
D3D10_MESSAGE_ID_CREATEQUERYORPREDICATE_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 233
D3D10_MESSAGE_ID_CREATEQUERYORPREDICATE_UNEXPECTEDMISCFLAG: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 234
D3D10_MESSAGE_ID_CREATEQUERYORPREDICATE_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 235
D3D10_MESSAGE_ID_DEVICE_IASETPRIMITIVETOPOLOGY_TOPOLOGY_UNRECOGNIZED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 236
D3D10_MESSAGE_ID_DEVICE_IASETPRIMITIVETOPOLOGY_TOPOLOGY_UNDEFINED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 237
D3D10_MESSAGE_ID_IASETVERTEXBUFFERS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 238
D3D10_MESSAGE_ID_DEVICE_IASETVERTEXBUFFERS_OFFSET_TOO_LARGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 239
D3D10_MESSAGE_ID_DEVICE_IASETVERTEXBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 240
D3D10_MESSAGE_ID_IASETINDEXBUFFER_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 241
D3D10_MESSAGE_ID_DEVICE_IASETINDEXBUFFER_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 242
D3D10_MESSAGE_ID_DEVICE_IASETINDEXBUFFER_OFFSET_TOO_LARGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 243
D3D10_MESSAGE_ID_DEVICE_IASETINDEXBUFFER_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 244
D3D10_MESSAGE_ID_DEVICE_VSSETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 245
D3D10_MESSAGE_ID_VSSETCONSTANTBUFFERS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 246
D3D10_MESSAGE_ID_DEVICE_VSSETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 247
D3D10_MESSAGE_ID_DEVICE_VSSETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 248
D3D10_MESSAGE_ID_DEVICE_GSSETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 249
D3D10_MESSAGE_ID_GSSETCONSTANTBUFFERS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 250
D3D10_MESSAGE_ID_DEVICE_GSSETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 251
D3D10_MESSAGE_ID_DEVICE_GSSETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 252
D3D10_MESSAGE_ID_SOSETTARGETS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 253
D3D10_MESSAGE_ID_DEVICE_SOSETTARGETS_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 254
D3D10_MESSAGE_ID_DEVICE_PSSETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 255
D3D10_MESSAGE_ID_PSSETCONSTANTBUFFERS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 256
D3D10_MESSAGE_ID_DEVICE_PSSETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 257
D3D10_MESSAGE_ID_DEVICE_PSSETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 258
D3D10_MESSAGE_ID_DEVICE_RSSETVIEWPORTS_INVALIDVIEWPORT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 259
D3D10_MESSAGE_ID_DEVICE_RSSETSCISSORRECTS_INVALIDSCISSOR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 260
D3D10_MESSAGE_ID_CLEARRENDERTARGETVIEW_DENORMFLUSH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 261
D3D10_MESSAGE_ID_CLEARDEPTHSTENCILVIEW_DENORMFLUSH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 262
D3D10_MESSAGE_ID_CLEARDEPTHSTENCILVIEW_INVALID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 263
D3D10_MESSAGE_ID_DEVICE_IAGETVERTEXBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 264
D3D10_MESSAGE_ID_DEVICE_VSGETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 265
D3D10_MESSAGE_ID_DEVICE_VSGETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 266
D3D10_MESSAGE_ID_DEVICE_VSGETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 267
D3D10_MESSAGE_ID_DEVICE_GSGETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 268
D3D10_MESSAGE_ID_DEVICE_GSGETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 269
D3D10_MESSAGE_ID_DEVICE_GSGETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 270
D3D10_MESSAGE_ID_DEVICE_SOGETTARGETS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 271
D3D10_MESSAGE_ID_DEVICE_PSGETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 272
D3D10_MESSAGE_ID_DEVICE_PSGETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 273
D3D10_MESSAGE_ID_DEVICE_PSGETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 274
D3D10_MESSAGE_ID_DEVICE_RSGETVIEWPORTS_VIEWPORTS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 275
D3D10_MESSAGE_ID_DEVICE_RSGETSCISSORRECTS_RECTS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 276
D3D10_MESSAGE_ID_DEVICE_GENERATEMIPS_RESOURCE_INVALID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 277
D3D10_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDDESTINATIONSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 278
D3D10_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDSOURCESUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 279
D3D10_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDSOURCEBOX: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 280
D3D10_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDSOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 281
D3D10_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDDESTINATIONSTATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 282
D3D10_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDSOURCESTATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 283
D3D10_MESSAGE_ID_COPYRESOURCE_INVALIDSOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 284
D3D10_MESSAGE_ID_COPYRESOURCE_INVALIDDESTINATIONSTATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 285
D3D10_MESSAGE_ID_COPYRESOURCE_INVALIDSOURCESTATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 286
D3D10_MESSAGE_ID_UPDATESUBRESOURCE_INVALIDDESTINATIONSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 287
D3D10_MESSAGE_ID_UPDATESUBRESOURCE_INVALIDDESTINATIONBOX: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 288
D3D10_MESSAGE_ID_UPDATESUBRESOURCE_INVALIDDESTINATIONSTATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 289
D3D10_MESSAGE_ID_DEVICE_RESOLVESUBRESOURCE_DESTINATION_INVALID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 290
D3D10_MESSAGE_ID_DEVICE_RESOLVESUBRESOURCE_DESTINATION_SUBRESOURCE_INVALID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 291
D3D10_MESSAGE_ID_DEVICE_RESOLVESUBRESOURCE_SOURCE_INVALID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 292
D3D10_MESSAGE_ID_DEVICE_RESOLVESUBRESOURCE_SOURCE_SUBRESOURCE_INVALID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 293
D3D10_MESSAGE_ID_DEVICE_RESOLVESUBRESOURCE_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 294
D3D10_MESSAGE_ID_BUFFER_MAP_INVALIDMAPTYPE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 295
D3D10_MESSAGE_ID_BUFFER_MAP_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 296
D3D10_MESSAGE_ID_BUFFER_MAP_ALREADYMAPPED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 297
D3D10_MESSAGE_ID_BUFFER_MAP_DEVICEREMOVED_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 298
D3D10_MESSAGE_ID_BUFFER_UNMAP_NOTMAPPED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 299
D3D10_MESSAGE_ID_TEXTURE1D_MAP_INVALIDMAPTYPE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 300
D3D10_MESSAGE_ID_TEXTURE1D_MAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 301
D3D10_MESSAGE_ID_TEXTURE1D_MAP_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 302
D3D10_MESSAGE_ID_TEXTURE1D_MAP_ALREADYMAPPED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 303
D3D10_MESSAGE_ID_TEXTURE1D_MAP_DEVICEREMOVED_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 304
D3D10_MESSAGE_ID_TEXTURE1D_UNMAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 305
D3D10_MESSAGE_ID_TEXTURE1D_UNMAP_NOTMAPPED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 306
D3D10_MESSAGE_ID_TEXTURE2D_MAP_INVALIDMAPTYPE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 307
D3D10_MESSAGE_ID_TEXTURE2D_MAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 308
D3D10_MESSAGE_ID_TEXTURE2D_MAP_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 309
D3D10_MESSAGE_ID_TEXTURE2D_MAP_ALREADYMAPPED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 310
D3D10_MESSAGE_ID_TEXTURE2D_MAP_DEVICEREMOVED_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 311
D3D10_MESSAGE_ID_TEXTURE2D_UNMAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 312
D3D10_MESSAGE_ID_TEXTURE2D_UNMAP_NOTMAPPED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 313
D3D10_MESSAGE_ID_TEXTURE3D_MAP_INVALIDMAPTYPE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 314
D3D10_MESSAGE_ID_TEXTURE3D_MAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 315
D3D10_MESSAGE_ID_TEXTURE3D_MAP_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 316
D3D10_MESSAGE_ID_TEXTURE3D_MAP_ALREADYMAPPED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 317
D3D10_MESSAGE_ID_TEXTURE3D_MAP_DEVICEREMOVED_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 318
D3D10_MESSAGE_ID_TEXTURE3D_UNMAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 319
D3D10_MESSAGE_ID_TEXTURE3D_UNMAP_NOTMAPPED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 320
D3D10_MESSAGE_ID_CHECKFORMATSUPPORT_FORMAT_DEPRECATED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 321
D3D10_MESSAGE_ID_CHECKMULTISAMPLEQUALITYLEVELS_FORMAT_DEPRECATED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 322
D3D10_MESSAGE_ID_SETEXCEPTIONMODE_UNRECOGNIZEDFLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 323
D3D10_MESSAGE_ID_SETEXCEPTIONMODE_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 324
D3D10_MESSAGE_ID_SETEXCEPTIONMODE_DEVICEREMOVED_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 325
D3D10_MESSAGE_ID_REF_SIMULATING_INFINITELY_FAST_HARDWARE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 326
D3D10_MESSAGE_ID_REF_THREADING_MODE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 327
D3D10_MESSAGE_ID_REF_UMDRIVER_EXCEPTION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 328
D3D10_MESSAGE_ID_REF_KMDRIVER_EXCEPTION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 329
D3D10_MESSAGE_ID_REF_HARDWARE_EXCEPTION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 330
D3D10_MESSAGE_ID_REF_ACCESSING_INDEXABLE_TEMP_OUT_OF_RANGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 331
D3D10_MESSAGE_ID_REF_PROBLEM_PARSING_SHADER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 332
D3D10_MESSAGE_ID_REF_OUT_OF_MEMORY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 333
D3D10_MESSAGE_ID_REF_INFO: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 334
D3D10_MESSAGE_ID_DEVICE_DRAW_VERTEXPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 335
D3D10_MESSAGE_ID_DEVICE_DRAWINDEXED_INDEXPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 336
D3D10_MESSAGE_ID_DEVICE_DRAWINSTANCED_VERTEXPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 337
D3D10_MESSAGE_ID_DEVICE_DRAWINSTANCED_INSTANCEPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 338
D3D10_MESSAGE_ID_DEVICE_DRAWINDEXEDINSTANCED_INSTANCEPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 339
D3D10_MESSAGE_ID_DEVICE_DRAWINDEXEDINSTANCED_INDEXPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 340
D3D10_MESSAGE_ID_DEVICE_DRAW_VERTEX_SHADER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 341
D3D10_MESSAGE_ID_DEVICE_SHADER_LINKAGE_SEMANTICNAME_NOT_FOUND: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 342
D3D10_MESSAGE_ID_DEVICE_SHADER_LINKAGE_REGISTERINDEX: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 343
D3D10_MESSAGE_ID_DEVICE_SHADER_LINKAGE_COMPONENTTYPE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 344
D3D10_MESSAGE_ID_DEVICE_SHADER_LINKAGE_REGISTERMASK: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 345
D3D10_MESSAGE_ID_DEVICE_SHADER_LINKAGE_SYSTEMVALUE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 346
D3D10_MESSAGE_ID_DEVICE_SHADER_LINKAGE_NEVERWRITTEN_ALWAYSREADS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 347
D3D10_MESSAGE_ID_DEVICE_DRAW_VERTEX_BUFFER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 348
D3D10_MESSAGE_ID_DEVICE_DRAW_INPUTLAYOUT_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 349
D3D10_MESSAGE_ID_DEVICE_DRAW_CONSTANT_BUFFER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 350
D3D10_MESSAGE_ID_DEVICE_DRAW_CONSTANT_BUFFER_TOO_SMALL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 351
D3D10_MESSAGE_ID_DEVICE_DRAW_SAMPLER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 352
D3D10_MESSAGE_ID_DEVICE_DRAW_SHADERRESOURCEVIEW_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 353
D3D10_MESSAGE_ID_DEVICE_DRAW_VIEW_DIMENSION_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 354
D3D10_MESSAGE_ID_DEVICE_DRAW_VERTEX_BUFFER_STRIDE_TOO_SMALL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 355
D3D10_MESSAGE_ID_DEVICE_DRAW_VERTEX_BUFFER_TOO_SMALL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 356
D3D10_MESSAGE_ID_DEVICE_DRAW_INDEX_BUFFER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 357
D3D10_MESSAGE_ID_DEVICE_DRAW_INDEX_BUFFER_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 358
D3D10_MESSAGE_ID_DEVICE_DRAW_INDEX_BUFFER_TOO_SMALL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 359
D3D10_MESSAGE_ID_DEVICE_DRAW_GS_INPUT_PRIMITIVE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 360
D3D10_MESSAGE_ID_DEVICE_DRAW_RESOURCE_RETURN_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 361
D3D10_MESSAGE_ID_DEVICE_DRAW_POSITION_NOT_PRESENT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 362
D3D10_MESSAGE_ID_DEVICE_DRAW_OUTPUT_STREAM_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 363
D3D10_MESSAGE_ID_DEVICE_DRAW_BOUND_RESOURCE_MAPPED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 364
D3D10_MESSAGE_ID_DEVICE_DRAW_INVALID_PRIMITIVETOPOLOGY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 365
D3D10_MESSAGE_ID_DEVICE_DRAW_VERTEX_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 366
D3D10_MESSAGE_ID_DEVICE_DRAW_VERTEX_STRIDE_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 367
D3D10_MESSAGE_ID_DEVICE_DRAW_INDEX_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 368
D3D10_MESSAGE_ID_DEVICE_DRAW_OUTPUT_STREAM_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 369
D3D10_MESSAGE_ID_DEVICE_DRAW_RESOURCE_FORMAT_LD_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 370
D3D10_MESSAGE_ID_DEVICE_DRAW_RESOURCE_FORMAT_SAMPLE_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 371
D3D10_MESSAGE_ID_DEVICE_DRAW_RESOURCE_FORMAT_SAMPLE_C_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 372
D3D10_MESSAGE_ID_DEVICE_DRAW_RESOURCE_MULTISAMPLE_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 373
D3D10_MESSAGE_ID_DEVICE_DRAW_SO_TARGETS_BOUND_WITHOUT_SOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 374
D3D10_MESSAGE_ID_DEVICE_DRAW_SO_STRIDE_LARGER_THAN_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 375
D3D10_MESSAGE_ID_DEVICE_DRAW_OM_RENDER_TARGET_DOES_NOT_SUPPORT_BLENDING: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 376
D3D10_MESSAGE_ID_DEVICE_DRAW_OM_DUAL_SOURCE_BLENDING_CAN_ONLY_HAVE_RENDER_TARGET_0: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 377
D3D10_MESSAGE_ID_DEVICE_REMOVAL_PROCESS_AT_FAULT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 378
D3D10_MESSAGE_ID_DEVICE_REMOVAL_PROCESS_POSSIBLY_AT_FAULT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 379
D3D10_MESSAGE_ID_DEVICE_REMOVAL_PROCESS_NOT_AT_FAULT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 380
D3D10_MESSAGE_ID_DEVICE_OPEN_SHARED_RESOURCE_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 381
D3D10_MESSAGE_ID_DEVICE_OPEN_SHARED_RESOURCE_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 382
D3D10_MESSAGE_ID_DEVICE_OPEN_SHARED_RESOURCE_BADINTERFACE_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 383
D3D10_MESSAGE_ID_DEVICE_DRAW_VIEWPORT_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 384
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_TRAILING_DIGIT_IN_SEMANTIC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 385
D3D10_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_TRAILING_DIGIT_IN_SEMANTIC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 386
D3D10_MESSAGE_ID_DEVICE_RSSETVIEWPORTS_DENORMFLUSH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 387
D3D10_MESSAGE_ID_OMSETRENDERTARGETS_INVALIDVIEW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 388
D3D10_MESSAGE_ID_DEVICE_SETTEXTFILTERSIZE_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 389
D3D10_MESSAGE_ID_DEVICE_DRAW_SAMPLER_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 390
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 391
D3D10_MESSAGE_ID_BLENDSTATE_GETDESC_LEGACY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 392
D3D10_MESSAGE_ID_SHADERRESOURCEVIEW_GETDESC_LEGACY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 393
D3D10_MESSAGE_ID_CREATEQUERY_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 394
D3D10_MESSAGE_ID_CREATEPREDICATE_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 395
D3D10_MESSAGE_ID_CREATECOUNTER_OUTOFRANGE_COUNTER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 396
D3D10_MESSAGE_ID_CREATECOUNTER_SIMULTANEOUS_ACTIVE_COUNTERS_EXHAUSTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 397
D3D10_MESSAGE_ID_CREATECOUNTER_UNSUPPORTED_WELLKNOWN_COUNTER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 398
D3D10_MESSAGE_ID_CREATECOUNTER_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 399
D3D10_MESSAGE_ID_CREATECOUNTER_NONEXCLUSIVE_RETURN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 400
D3D10_MESSAGE_ID_CREATECOUNTER_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 401
D3D10_MESSAGE_ID_CHECKCOUNTER_OUTOFRANGE_COUNTER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 402
D3D10_MESSAGE_ID_CHECKCOUNTER_UNSUPPORTED_WELLKNOWN_COUNTER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 403
D3D10_MESSAGE_ID_SETPREDICATION_INVALID_PREDICATE_STATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 404
D3D10_MESSAGE_ID_QUERY_BEGIN_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 405
D3D10_MESSAGE_ID_PREDICATE_BEGIN_DURING_PREDICATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 406
D3D10_MESSAGE_ID_QUERY_BEGIN_DUPLICATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 407
D3D10_MESSAGE_ID_QUERY_BEGIN_ABANDONING_PREVIOUS_RESULTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 408
D3D10_MESSAGE_ID_PREDICATE_END_DURING_PREDICATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 409
D3D10_MESSAGE_ID_QUERY_END_ABANDONING_PREVIOUS_RESULTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 410
D3D10_MESSAGE_ID_QUERY_END_WITHOUT_BEGIN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 411
D3D10_MESSAGE_ID_QUERY_GETDATA_INVALID_DATASIZE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 412
D3D10_MESSAGE_ID_QUERY_GETDATA_INVALID_FLAGS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 413
D3D10_MESSAGE_ID_QUERY_GETDATA_INVALID_CALL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 414
D3D10_MESSAGE_ID_DEVICE_DRAW_PS_OUTPUT_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 415
D3D10_MESSAGE_ID_DEVICE_DRAW_RESOURCE_FORMAT_GATHER_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 416
D3D10_MESSAGE_ID_DEVICE_DRAW_INVALID_USE_OF_CENTER_MULTISAMPLE_PATTERN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 417
D3D10_MESSAGE_ID_DEVICE_IASETVERTEXBUFFERS_STRIDE_TOO_LARGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 418
D3D10_MESSAGE_ID_DEVICE_IASETVERTEXBUFFERS_INVALIDRANGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 419
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_EMPTY_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 420
D3D10_MESSAGE_ID_DEVICE_DRAW_RESOURCE_SAMPLE_COUNT_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 421
D3D10_MESSAGE_ID_LIVE_OBJECT_SUMMARY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 422
D3D10_MESSAGE_ID_LIVE_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 423
D3D10_MESSAGE_ID_LIVE_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 424
D3D10_MESSAGE_ID_LIVE_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 425
D3D10_MESSAGE_ID_LIVE_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 426
D3D10_MESSAGE_ID_LIVE_SHADERRESOURCEVIEW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 427
D3D10_MESSAGE_ID_LIVE_RENDERTARGETVIEW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 428
D3D10_MESSAGE_ID_LIVE_DEPTHSTENCILVIEW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 429
D3D10_MESSAGE_ID_LIVE_VERTEXSHADER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 430
D3D10_MESSAGE_ID_LIVE_GEOMETRYSHADER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 431
D3D10_MESSAGE_ID_LIVE_PIXELSHADER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 432
D3D10_MESSAGE_ID_LIVE_INPUTLAYOUT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 433
D3D10_MESSAGE_ID_LIVE_SAMPLER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 434
D3D10_MESSAGE_ID_LIVE_BLENDSTATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 435
D3D10_MESSAGE_ID_LIVE_DEPTHSTENCILSTATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 436
D3D10_MESSAGE_ID_LIVE_RASTERIZERSTATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 437
D3D10_MESSAGE_ID_LIVE_QUERY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 438
D3D10_MESSAGE_ID_LIVE_PREDICATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 439
D3D10_MESSAGE_ID_LIVE_COUNTER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 440
D3D10_MESSAGE_ID_LIVE_DEVICE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 441
D3D10_MESSAGE_ID_LIVE_SWAPCHAIN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 442
D3D10_MESSAGE_ID_D3D10_MESSAGES_END: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 443
D3D10_MESSAGE_ID_D3D10L9_MESSAGES_START: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048576
D3D10_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_STENCIL_NO_TWO_SIDED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048577
D3D10_MESSAGE_ID_CREATERASTERIZERSTATE_DepthBiasClamp_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048578
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_NO_COMPARISON_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048579
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_EXCESSIVE_ANISOTROPY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048580
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_BORDER_OUT_OF_RANGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048581
D3D10_MESSAGE_ID_VSSETSAMPLERS_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048582
D3D10_MESSAGE_ID_VSSETSAMPLERS_TOO_MANY_SAMPLERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048583
D3D10_MESSAGE_ID_PSSETSAMPLERS_TOO_MANY_SAMPLERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048584
D3D10_MESSAGE_ID_CREATERESOURCE_NO_ARRAYS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048585
D3D10_MESSAGE_ID_CREATERESOURCE_NO_VB_AND_IB_BIND: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048586
D3D10_MESSAGE_ID_CREATERESOURCE_NO_TEXTURE_1D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048587
D3D10_MESSAGE_ID_CREATERESOURCE_DIMENSION_OUT_OF_RANGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048588
D3D10_MESSAGE_ID_CREATERESOURCE_NOT_BINDABLE_AS_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048589
D3D10_MESSAGE_ID_OMSETRENDERTARGETS_TOO_MANY_RENDER_TARGETS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048590
D3D10_MESSAGE_ID_OMSETRENDERTARGETS_NO_DIFFERING_BIT_DEPTHS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048591
D3D10_MESSAGE_ID_IASETVERTEXBUFFERS_BAD_BUFFER_INDEX: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048592
D3D10_MESSAGE_ID_DEVICE_RSSETVIEWPORTS_TOO_MANY_VIEWPORTS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048593
D3D10_MESSAGE_ID_DEVICE_IASETPRIMITIVETOPOLOGY_ADJACENCY_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048594
D3D10_MESSAGE_ID_DEVICE_RSSETSCISSORRECTS_TOO_MANY_SCISSORS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048595
D3D10_MESSAGE_ID_COPYRESOURCE_ONLY_TEXTURE_2D_WITHIN_GPU_MEMORY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048596
D3D10_MESSAGE_ID_COPYRESOURCE_NO_TEXTURE_3D_READBACK: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048597
D3D10_MESSAGE_ID_COPYRESOURCE_NO_TEXTURE_ONLY_READBACK: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048598
D3D10_MESSAGE_ID_CREATEINPUTLAYOUT_UNSUPPORTED_FORMAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048599
D3D10_MESSAGE_ID_CREATEBLENDSTATE_NO_ALPHA_TO_COVERAGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048600
D3D10_MESSAGE_ID_CREATERASTERIZERSTATE_DepthClipEnable_MUST_BE_TRUE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048601
D3D10_MESSAGE_ID_DRAWINDEXED_STARTINDEXLOCATION_MUST_BE_POSITIVE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048602
D3D10_MESSAGE_ID_CREATESHADERRESOURCEVIEW_MUST_USE_LOWEST_LOD: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048603
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_MINLOD_MUST_NOT_BE_FRACTIONAL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048604
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_MAXLOD_MUST_BE_FLT_MAX: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048605
D3D10_MESSAGE_ID_CREATESHADERRESOURCEVIEW_FIRSTARRAYSLICE_MUST_BE_ZERO: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048606
D3D10_MESSAGE_ID_CREATESHADERRESOURCEVIEW_CUBES_MUST_HAVE_6_SIDES: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048607
D3D10_MESSAGE_ID_CREATERESOURCE_NOT_BINDABLE_AS_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048608
D3D10_MESSAGE_ID_CREATERESOURCE_NO_DWORD_INDEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048609
D3D10_MESSAGE_ID_CREATERESOURCE_MSAA_PRECLUDES_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048610
D3D10_MESSAGE_ID_CREATERESOURCE_PRESENTATION_PRECLUDES_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048611
D3D10_MESSAGE_ID_CREATEBLENDSTATE_NO_INDEPENDENT_BLEND_ENABLE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048612
D3D10_MESSAGE_ID_CREATEBLENDSTATE_NO_INDEPENDENT_WRITE_MASKS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048613
D3D10_MESSAGE_ID_CREATERESOURCE_NO_STREAM_OUT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048614
D3D10_MESSAGE_ID_CREATERESOURCE_ONLY_VB_IB_FOR_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048615
D3D10_MESSAGE_ID_CREATERESOURCE_NO_AUTOGEN_FOR_VOLUMES: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048616
D3D10_MESSAGE_ID_CREATERESOURCE_DXGI_FORMAT_R8G8B8A8_CANNOT_BE_SHARED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048617
D3D10_MESSAGE_ID_VSSHADERRESOURCES_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048618
D3D10_MESSAGE_ID_GEOMETRY_SHADER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048619
D3D10_MESSAGE_ID_STREAM_OUT_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048620
D3D10_MESSAGE_ID_TEXT_FILTER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048621
D3D10_MESSAGE_ID_CREATEBLENDSTATE_NO_SEPARATE_ALPHA_BLEND: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048622
D3D10_MESSAGE_ID_CREATEBLENDSTATE_NO_MRT_BLEND: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048623
D3D10_MESSAGE_ID_CREATEBLENDSTATE_OPERATION_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048624
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_NO_MIRRORONCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048625
D3D10_MESSAGE_ID_DRAWINSTANCED_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048626
D3D10_MESSAGE_ID_DRAWINDEXEDINSTANCED_NOT_SUPPORTED_BELOW_9_3: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048627
D3D10_MESSAGE_ID_DRAWINDEXED_POINTLIST_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048628
D3D10_MESSAGE_ID_SETBLENDSTATE_SAMPLE_MASK_CANNOT_BE_ZERO: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048629
D3D10_MESSAGE_ID_CREATERESOURCE_DIMENSION_EXCEEDS_FEATURE_LEVEL_DEFINITION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048630
D3D10_MESSAGE_ID_CREATERESOURCE_ONLY_SINGLE_MIP_LEVEL_DEPTH_STENCIL_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048631
D3D10_MESSAGE_ID_DEVICE_RSSETSCISSORRECTS_NEGATIVESCISSOR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048632
D3D10_MESSAGE_ID_SLOT_ZERO_MUST_BE_D3D10_INPUT_PER_VERTEX_DATA: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048633
D3D10_MESSAGE_ID_CREATERESOURCE_NON_POW_2_MIPMAP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048634
D3D10_MESSAGE_ID_CREATESAMPLERSTATE_BORDER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048635
D3D10_MESSAGE_ID_OMSETRENDERTARGETS_NO_SRGB_MRT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048636
D3D10_MESSAGE_ID_COPYRESOURCE_NO_3D_MISMATCHED_UPDATES: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048637
D3D10_MESSAGE_ID_D3D10L9_MESSAGES_END: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID = 1048638
D3D10_MESSAGE_SEVERITY = Int32
D3D10_MESSAGE_SEVERITY_CORRUPTION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_SEVERITY = 0
D3D10_MESSAGE_SEVERITY_ERROR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_SEVERITY = 1
D3D10_MESSAGE_SEVERITY_WARNING: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_SEVERITY = 2
D3D10_MESSAGE_SEVERITY_INFO: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_SEVERITY = 3
D3D10_MESSAGE_SEVERITY_MESSAGE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_SEVERITY = 4
class D3D10_PASS_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    Annotations: UInt32
    pIAInputSignature: POINTER(Byte)
    IAInputSignatureSize: UIntPtr
    StencilRef: UInt32
    SampleMask: UInt32
    BlendFactor: Single * 4
class D3D10_PASS_SHADER_DESC(Structure):
    pShaderVariable: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectShaderVariable
    ShaderIndex: UInt32
D3D10_QUERY = Int32
D3D10_QUERY_EVENT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY = 0
D3D10_QUERY_OCCLUSION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY = 1
D3D10_QUERY_TIMESTAMP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY = 2
D3D10_QUERY_TIMESTAMP_DISJOINT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY = 3
D3D10_QUERY_PIPELINE_STATISTICS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY = 4
D3D10_QUERY_OCCLUSION_PREDICATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY = 5
D3D10_QUERY_SO_STATISTICS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY = 6
D3D10_QUERY_SO_OVERFLOW_PREDICATE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY = 7
class D3D10_QUERY_DATA_PIPELINE_STATISTICS(Structure):
    IAVertices: UInt64
    IAPrimitives: UInt64
    VSInvocations: UInt64
    GSInvocations: UInt64
    GSPrimitives: UInt64
    CInvocations: UInt64
    CPrimitives: UInt64
    PSInvocations: UInt64
class D3D10_QUERY_DATA_SO_STATISTICS(Structure):
    NumPrimitivesWritten: UInt64
    PrimitivesStorageNeeded: UInt64
class D3D10_QUERY_DATA_TIMESTAMP_DISJOINT(Structure):
    Frequency: UInt64
    Disjoint: win32more.Windows.Win32.Foundation.BOOL
class D3D10_QUERY_DESC(Structure):
    Query: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY
    MiscFlags: UInt32
D3D10_QUERY_MISC_FLAG = Int32
D3D10_QUERY_MISC_PREDICATEHINT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY_MISC_FLAG = 1
D3D10_RAISE_FLAG = Int32
D3D10_RAISE_FLAG_DRIVER_INTERNAL_ERROR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RAISE_FLAG = 1
class D3D10_RASTERIZER_DESC(Structure):
    FillMode: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILL_MODE
    CullMode: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_CULL_MODE
    FrontCounterClockwise: win32more.Windows.Win32.Foundation.BOOL
    DepthBias: Int32
    DepthBiasClamp: Single
    SlopeScaledDepthBias: Single
    DepthClipEnable: win32more.Windows.Win32.Foundation.BOOL
    ScissorEnable: win32more.Windows.Win32.Foundation.BOOL
    MultisampleEnable: win32more.Windows.Win32.Foundation.BOOL
    AntialiasedLineEnable: win32more.Windows.Win32.Foundation.BOOL
class D3D10_RENDER_TARGET_BLEND_DESC1(Structure):
    BlendEnable: win32more.Windows.Win32.Foundation.BOOL
    SrcBlend: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND
    DestBlend: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND
    BlendOp: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_OP
    SrcBlendAlpha: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND
    DestBlendAlpha: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND
    BlendOpAlpha: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_OP
    RenderTargetWriteMask: Byte
class D3D10_RENDER_TARGET_VIEW_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RTV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BUFFER_RTV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX1D_RTV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX1D_ARRAY_RTV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2D_RTV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2D_ARRAY_RTV
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2DMS_RTV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2DMS_ARRAY_RTV
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX3D_RTV
D3D10_RESOURCE_DIMENSION = Int32
D3D10_RESOURCE_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RESOURCE_DIMENSION = 0
D3D10_RESOURCE_DIMENSION_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RESOURCE_DIMENSION = 1
D3D10_RESOURCE_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RESOURCE_DIMENSION = 2
D3D10_RESOURCE_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RESOURCE_DIMENSION = 3
D3D10_RESOURCE_DIMENSION_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RESOURCE_DIMENSION = 4
D3D10_RESOURCE_MISC_FLAG = Int32
D3D10_RESOURCE_MISC_GENERATE_MIPS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RESOURCE_MISC_FLAG = 1
D3D10_RESOURCE_MISC_SHARED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RESOURCE_MISC_FLAG = 2
D3D10_RESOURCE_MISC_TEXTURECUBE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RESOURCE_MISC_FLAG = 4
D3D10_RESOURCE_MISC_SHARED_KEYEDMUTEX: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RESOURCE_MISC_FLAG = 16
D3D10_RESOURCE_MISC_GDI_COMPATIBLE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RESOURCE_MISC_FLAG = 32
D3D10_RTV_DIMENSION = Int32
D3D10_RTV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RTV_DIMENSION = 0
D3D10_RTV_DIMENSION_BUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RTV_DIMENSION = 1
D3D10_RTV_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RTV_DIMENSION = 2
D3D10_RTV_DIMENSION_TEXTURE1DARRAY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RTV_DIMENSION = 3
D3D10_RTV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RTV_DIMENSION = 4
D3D10_RTV_DIMENSION_TEXTURE2DARRAY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RTV_DIMENSION = 5
D3D10_RTV_DIMENSION_TEXTURE2DMS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RTV_DIMENSION = 6
D3D10_RTV_DIMENSION_TEXTURE2DMSARRAY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RTV_DIMENSION = 7
D3D10_RTV_DIMENSION_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RTV_DIMENSION = 8
class D3D10_SAMPLER_DESC(Structure):
    Filter: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FILTER
    AddressU: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE_ADDRESS_MODE
    AddressV: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE_ADDRESS_MODE
    AddressW: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE_ADDRESS_MODE
    MipLODBias: Single
    MaxAnisotropy: UInt32
    ComparisonFunc: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COMPARISON_FUNC
    BorderColor: Single * 4
    MinLOD: Single
    MaxLOD: Single
class D3D10_SHADER_BUFFER_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_CBUFFER_TYPE
    Variables: UInt32
    Size: UInt32
    uFlags: UInt32
class D3D10_SHADER_DEBUG_FILE_INFO(Structure):
    FileName: UInt32
    FileNameLen: UInt32
    FileData: UInt32
    FileLen: UInt32
class D3D10_SHADER_DEBUG_INFO(Structure):
    Size: UInt32
    Creator: UInt32
    EntrypointName: UInt32
    ShaderTarget: UInt32
    CompileFlags: UInt32
    Files: UInt32
    FileInfo: UInt32
    Instructions: UInt32
    InstructionInfo: UInt32
    Variables: UInt32
    VariableInfo: UInt32
    InputVariables: UInt32
    InputVariableInfo: UInt32
    Tokens: UInt32
    TokenInfo: UInt32
    Scopes: UInt32
    ScopeInfo: UInt32
    ScopeVariables: UInt32
    ScopeVariableInfo: UInt32
    UintOffset: UInt32
    StringOffset: UInt32
class D3D10_SHADER_DEBUG_INPUT_INFO(Structure):
    Var: UInt32
    InitialRegisterSet: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE
    InitialBank: UInt32
    InitialRegister: UInt32
    InitialComponent: UInt32
    InitialValue: UInt32
class D3D10_SHADER_DEBUG_INST_INFO(Structure):
    Id: UInt32
    Opcode: UInt32
    uOutputs: UInt32
    pOutputs: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_OUTPUTREG_INFO * 2
    TokenId: UInt32
    NestingLevel: UInt32
    Scopes: UInt32
    ScopeInfo: UInt32
    AccessedVars: UInt32
    AccessedVarsInfo: UInt32
class D3D10_SHADER_DEBUG_OUTPUTREG_INFO(Structure):
    OutputRegisterSet: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE
    OutputReg: UInt32
    TempArrayReg: UInt32
    OutputComponents: UInt32 * 4
    OutputVars: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_OUTPUTVAR * 4
    IndexReg: UInt32
    IndexComp: UInt32
class D3D10_SHADER_DEBUG_OUTPUTVAR(Structure):
    Var: UInt32
    uValueMin: UInt32
    uValueMax: UInt32
    iValueMin: Int32
    iValueMax: Int32
    fValueMin: Single
    fValueMax: Single
    bNaNPossible: win32more.Windows.Win32.Foundation.BOOL
    bInfPossible: win32more.Windows.Win32.Foundation.BOOL
D3D10_SHADER_DEBUG_REGTYPE = Int32
D3D10_SHADER_DEBUG_REG_INPUT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 0
D3D10_SHADER_DEBUG_REG_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 1
D3D10_SHADER_DEBUG_REG_CBUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 2
D3D10_SHADER_DEBUG_REG_TBUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 3
D3D10_SHADER_DEBUG_REG_TEMP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 4
D3D10_SHADER_DEBUG_REG_TEMPARRAY: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 5
D3D10_SHADER_DEBUG_REG_TEXTURE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 6
D3D10_SHADER_DEBUG_REG_SAMPLER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 7
D3D10_SHADER_DEBUG_REG_IMMEDIATECBUFFER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 8
D3D10_SHADER_DEBUG_REG_LITERAL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 9
D3D10_SHADER_DEBUG_REG_UNUSED: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 10
D3D11_SHADER_DEBUG_REG_INTERFACE_POINTERS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 11
D3D11_SHADER_DEBUG_REG_UAV: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_REGTYPE = 12
D3D10_SHADER_DEBUG_SCOPETYPE = Int32
D3D10_SHADER_DEBUG_SCOPE_GLOBAL: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_SCOPETYPE = 0
D3D10_SHADER_DEBUG_SCOPE_BLOCK: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_SCOPETYPE = 1
D3D10_SHADER_DEBUG_SCOPE_FORLOOP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_SCOPETYPE = 2
D3D10_SHADER_DEBUG_SCOPE_STRUCT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_SCOPETYPE = 3
D3D10_SHADER_DEBUG_SCOPE_FUNC_PARAMS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_SCOPETYPE = 4
D3D10_SHADER_DEBUG_SCOPE_STATEBLOCK: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_SCOPETYPE = 5
D3D10_SHADER_DEBUG_SCOPE_NAMESPACE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_SCOPETYPE = 6
D3D10_SHADER_DEBUG_SCOPE_ANNOTATION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_SCOPETYPE = 7
class D3D10_SHADER_DEBUG_SCOPEVAR_INFO(Structure):
    TokenId: UInt32
    VarType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_VARTYPE
    Class: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_CLASS
    Rows: UInt32
    Columns: UInt32
    StructMemberScope: UInt32
    uArrayIndices: UInt32
    ArrayElements: UInt32
    ArrayStrides: UInt32
    uVariables: UInt32
    uFirstVariable: UInt32
class D3D10_SHADER_DEBUG_SCOPE_INFO(Structure):
    ScopeType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_SCOPETYPE
    Name: UInt32
    uNameLen: UInt32
    uVariables: UInt32
    VariableData: UInt32
class D3D10_SHADER_DEBUG_TOKEN_INFO(Structure):
    File: UInt32
    Line: UInt32
    Column: UInt32
    TokenLength: UInt32
    TokenId: UInt32
D3D10_SHADER_DEBUG_VARTYPE = Int32
D3D10_SHADER_DEBUG_VAR_VARIABLE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_VARTYPE = 0
D3D10_SHADER_DEBUG_VAR_FUNCTION: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DEBUG_VARTYPE = 1
class D3D10_SHADER_DEBUG_VAR_INFO(Structure):
    TokenId: UInt32
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_TYPE
    Register: UInt32
    Component: UInt32
    ScopeVar: UInt32
    ScopeVarOffset: UInt32
class D3D10_SHADER_DESC(Structure):
    Version: UInt32
    Creator: win32more.Windows.Win32.Foundation.PSTR
    Flags: UInt32
    ConstantBuffers: UInt32
    BoundResources: UInt32
    InputParameters: UInt32
    OutputParameters: UInt32
    InstructionCount: UInt32
    TempRegisterCount: UInt32
    TempArrayCount: UInt32
    DefCount: UInt32
    DclCount: UInt32
    TextureNormalInstructions: UInt32
    TextureLoadInstructions: UInt32
    TextureCompInstructions: UInt32
    TextureBiasInstructions: UInt32
    TextureGradientInstructions: UInt32
    FloatInstructionCount: UInt32
    IntInstructionCount: UInt32
    UintInstructionCount: UInt32
    StaticFlowControlCount: UInt32
    DynamicFlowControlCount: UInt32
    MacroInstructionCount: UInt32
    ArrayInstructionCount: UInt32
    CutInstructionCount: UInt32
    EmitInstructionCount: UInt32
    GSOutputTopology: win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE_TOPOLOGY
    GSMaxOutputVertexCount: UInt32
class D3D10_SHADER_INPUT_BIND_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_INPUT_TYPE
    BindPoint: UInt32
    BindCount: UInt32
    uFlags: UInt32
    ReturnType: win32more.Windows.Win32.Graphics.Direct3D.D3D_RESOURCE_RETURN_TYPE
    Dimension: win32more.Windows.Win32.Graphics.Direct3D.D3D_SRV_DIMENSION
    NumSamples: UInt32
class D3D10_SHADER_RESOURCE_VIEW_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D.D3D_SRV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BUFFER_SRV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX1D_SRV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX1D_ARRAY_SRV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2D_SRV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2D_ARRAY_SRV
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2DMS_SRV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2DMS_ARRAY_SRV
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX3D_SRV
        TextureCube: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXCUBE_SRV
class D3D10_SHADER_RESOURCE_VIEW_DESC1(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D.D3D_SRV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BUFFER_SRV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX1D_SRV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX1D_ARRAY_SRV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2D_SRV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2D_ARRAY_SRV
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2DMS_SRV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX2DMS_ARRAY_SRV
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEX3D_SRV
        TextureCube: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXCUBE_SRV
        TextureCubeArray: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXCUBE_ARRAY_SRV1
class D3D10_SHADER_TYPE_DESC(Structure):
    Class: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_CLASS
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_TYPE
    Rows: UInt32
    Columns: UInt32
    Elements: UInt32
    Members: UInt32
    Offset: UInt32
class D3D10_SHADER_VARIABLE_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    StartOffset: UInt32
    Size: UInt32
    uFlags: UInt32
    DefaultValue: VoidPtr
class D3D10_SIGNATURE_PARAMETER_DESC(Structure):
    SemanticName: win32more.Windows.Win32.Foundation.PSTR
    SemanticIndex: UInt32
    Register: UInt32
    SystemValueType: win32more.Windows.Win32.Graphics.Direct3D.D3D_NAME
    ComponentType: win32more.Windows.Win32.Graphics.Direct3D.D3D_REGISTER_COMPONENT_TYPE
    Mask: Byte
    ReadWriteMask: Byte
class D3D10_SO_DECLARATION_ENTRY(Structure):
    SemanticName: win32more.Windows.Win32.Foundation.PSTR
    SemanticIndex: UInt32
    StartComponent: Byte
    ComponentCount: Byte
    OutputSlot: Byte
D3D10_STANDARD_MULTISAMPLE_QUALITY_LEVELS = Int32
D3D10_STANDARD_MULTISAMPLE_PATTERN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STANDARD_MULTISAMPLE_QUALITY_LEVELS = -1
D3D10_CENTER_MULTISAMPLE_PATTERN: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STANDARD_MULTISAMPLE_QUALITY_LEVELS = -2
class D3D10_STATE_BLOCK_MASK(Structure):
    VS: Byte
    VSSamplers: Byte * 2
    VSShaderResources: Byte * 16
    VSConstantBuffers: Byte * 2
    GS: Byte
    GSSamplers: Byte * 2
    GSShaderResources: Byte * 16
    GSConstantBuffers: Byte * 2
    PS: Byte
    PSSamplers: Byte * 2
    PSShaderResources: Byte * 16
    PSConstantBuffers: Byte * 2
    IAVertexBuffers: Byte * 2
    IAIndexBuffer: Byte
    IAInputLayout: Byte
    IAPrimitiveTopology: Byte
    OMRenderTargets: Byte
    OMDepthStencilState: Byte
    OMBlendState: Byte
    RSViewports: Byte
    RSScissorRects: Byte
    RSRasterizerState: Byte
    SOBuffers: Byte
    Predication: Byte
D3D10_STENCIL_OP = Int32
D3D10_STENCIL_OP_KEEP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STENCIL_OP = 1
D3D10_STENCIL_OP_ZERO: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STENCIL_OP = 2
D3D10_STENCIL_OP_REPLACE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STENCIL_OP = 3
D3D10_STENCIL_OP_INCR_SAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STENCIL_OP = 4
D3D10_STENCIL_OP_DECR_SAT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STENCIL_OP = 5
D3D10_STENCIL_OP_INVERT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STENCIL_OP = 6
D3D10_STENCIL_OP_INCR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STENCIL_OP = 7
D3D10_STENCIL_OP_DECR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STENCIL_OP = 8
class D3D10_SUBRESOURCE_DATA(Structure):
    pSysMem: VoidPtr
    SysMemPitch: UInt32
    SysMemSlicePitch: UInt32
class D3D10_TECHNIQUE_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    Passes: UInt32
    Annotations: UInt32
class D3D10_TEX1D_ARRAY_DSV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D10_TEX1D_ARRAY_RTV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D10_TEX1D_ARRAY_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D10_TEX1D_DSV(Structure):
    MipSlice: UInt32
class D3D10_TEX1D_RTV(Structure):
    MipSlice: UInt32
class D3D10_TEX1D_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
class D3D10_TEX2DMS_ARRAY_DSV(Structure):
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D10_TEX2DMS_ARRAY_RTV(Structure):
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D10_TEX2DMS_ARRAY_SRV(Structure):
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D10_TEX2DMS_DSV(Structure):
    UnusedField_NothingToDefine: UInt32
class D3D10_TEX2DMS_RTV(Structure):
    UnusedField_NothingToDefine: UInt32
class D3D10_TEX2DMS_SRV(Structure):
    UnusedField_NothingToDefine: UInt32
class D3D10_TEX2D_ARRAY_DSV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D10_TEX2D_ARRAY_RTV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D10_TEX2D_ARRAY_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D10_TEX2D_DSV(Structure):
    MipSlice: UInt32
class D3D10_TEX2D_RTV(Structure):
    MipSlice: UInt32
class D3D10_TEX2D_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
class D3D10_TEX3D_RTV(Structure):
    MipSlice: UInt32
    FirstWSlice: UInt32
    WSize: UInt32
class D3D10_TEX3D_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
class D3D10_TEXCUBE_ARRAY_SRV1(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    First2DArrayFace: UInt32
    NumCubes: UInt32
class D3D10_TEXCUBE_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
class D3D10_TEXTURE1D_DESC(Structure):
    Width: UInt32
    MipLevels: UInt32
    ArraySize: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    Usage: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_USAGE
    BindFlags: UInt32
    CPUAccessFlags: UInt32
    MiscFlags: UInt32
class D3D10_TEXTURE2D_DESC(Structure):
    Width: UInt32
    Height: UInt32
    MipLevels: UInt32
    ArraySize: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    SampleDesc: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_SAMPLE_DESC
    Usage: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_USAGE
    BindFlags: UInt32
    CPUAccessFlags: UInt32
    MiscFlags: UInt32
class D3D10_TEXTURE3D_DESC(Structure):
    Width: UInt32
    Height: UInt32
    Depth: UInt32
    MipLevels: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    Usage: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_USAGE
    BindFlags: UInt32
    CPUAccessFlags: UInt32
    MiscFlags: UInt32
D3D10_TEXTURECUBE_FACE = Int32
D3D10_TEXTURECUBE_FACE_POSITIVE_X: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURECUBE_FACE = 0
D3D10_TEXTURECUBE_FACE_NEGATIVE_X: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURECUBE_FACE = 1
D3D10_TEXTURECUBE_FACE_POSITIVE_Y: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURECUBE_FACE = 2
D3D10_TEXTURECUBE_FACE_NEGATIVE_Y: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURECUBE_FACE = 3
D3D10_TEXTURECUBE_FACE_POSITIVE_Z: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURECUBE_FACE = 4
D3D10_TEXTURECUBE_FACE_NEGATIVE_Z: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURECUBE_FACE = 5
D3D10_TEXTURE_ADDRESS_MODE = Int32
D3D10_TEXTURE_ADDRESS_WRAP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE_ADDRESS_MODE = 1
D3D10_TEXTURE_ADDRESS_MIRROR: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE_ADDRESS_MODE = 2
D3D10_TEXTURE_ADDRESS_CLAMP: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE_ADDRESS_MODE = 3
D3D10_TEXTURE_ADDRESS_BORDER: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE_ADDRESS_MODE = 4
D3D10_TEXTURE_ADDRESS_MIRROR_ONCE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE_ADDRESS_MODE = 5
D3D10_USAGE = Int32
D3D10_USAGE_DEFAULT: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_USAGE = 0
D3D10_USAGE_IMMUTABLE: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_USAGE = 1
D3D10_USAGE_DYNAMIC: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_USAGE = 2
D3D10_USAGE_STAGING: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_USAGE = 3
class D3D10_VIEWPORT(Structure):
    TopLeftX: Int32
    TopLeftY: Int32
    Width: UInt32
    Height: UInt32
    MinDepth: Single
    MaxDepth: Single
class ID3D10Asynchronous(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DeviceChild
    _iid_ = Guid('{9b7e4c0d-342c-4106-a19f-4f2704f689f0}')
    @commethod(7)
    def Begin(self) -> Void: ...
    @commethod(8)
    def End(self) -> Void: ...
    @commethod(9)
    def GetData(self, pData: VoidPtr, DataSize: UInt32, GetDataFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetDataSize(self) -> UInt32: ...
class ID3D10BlendState(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DeviceChild
    _iid_ = Guid('{edad8d19-8a35-4d6d-8566-2ea276cde161}')
    @commethod(7)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_DESC)) -> Void: ...
class ID3D10BlendState1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10BlendState
    _iid_ = Guid('{edad8d99-8a35-4d6d-8566-2ea276cde161}')
    @commethod(8)
    def GetDesc1(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_DESC1)) -> Void: ...
class ID3D10Buffer(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource
    _iid_ = Guid('{9b7e4c02-342c-4106-a19f-4f2704f689f0}')
    @commethod(10)
    def Map(self, MapType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAP, MapFlags: UInt32, ppData: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Unmap(self) -> Void: ...
    @commethod(12)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BUFFER_DESC)) -> Void: ...
class ID3D10Counter(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Asynchronous
    _iid_ = Guid('{9b7e4c11-342c-4106-a19f-4f2704f689f0}')
    @commethod(11)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER_DESC)) -> Void: ...
class ID3D10Debug(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9b7e4e01-342c-4106-a19f-4f2704f689f0}')
    @commethod(3)
    def SetFeatureMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFeatureMask(self) -> UInt32: ...
    @commethod(5)
    def SetPresentPerRenderOpDelay(self, Milliseconds: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetPresentPerRenderOpDelay(self) -> UInt32: ...
    @commethod(7)
    def SetSwapChain(self, pSwapChain: win32more.Windows.Win32.Graphics.Dxgi.IDXGISwapChain) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetSwapChain(self, ppSwapChain: POINTER(win32more.Windows.Win32.Graphics.Dxgi.IDXGISwapChain)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Validate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10DepthStencilState(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DeviceChild
    _iid_ = Guid('{2b4b1cc8-a4ad-41f8-8322-ca86fc3ec675}')
    @commethod(7)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEPTH_STENCIL_DESC)) -> Void: ...
class ID3D10DepthStencilView(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10View
    _iid_ = Guid('{9b7e4c09-342c-4106-a19f-4f2704f689f0}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEPTH_STENCIL_VIEW_DESC)) -> Void: ...
class ID3D10Device(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9b7e4c0f-342c-4106-a19f-4f2704f689f0}')
    @commethod(3)
    def VSSetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer)) -> Void: ...
    @commethod(4)
    def PSSetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView)) -> Void: ...
    @commethod(5)
    def PSSetShader(self, pPixelShader: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10PixelShader) -> Void: ...
    @commethod(6)
    def PSSetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10SamplerState)) -> Void: ...
    @commethod(7)
    def VSSetShader(self, pVertexShader: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10VertexShader) -> Void: ...
    @commethod(8)
    def DrawIndexed(self, IndexCount: UInt32, StartIndexLocation: UInt32, BaseVertexLocation: Int32) -> Void: ...
    @commethod(9)
    def Draw(self, VertexCount: UInt32, StartVertexLocation: UInt32) -> Void: ...
    @commethod(10)
    def PSSetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer)) -> Void: ...
    @commethod(11)
    def IASetInputLayout(self, pInputLayout: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10InputLayout) -> Void: ...
    @commethod(12)
    def IASetVertexBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppVertexBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer), pStrides: POINTER(UInt32), pOffsets: POINTER(UInt32)) -> Void: ...
    @commethod(13)
    def IASetIndexBuffer(self, pIndexBuffer: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer, Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, Offset: UInt32) -> Void: ...
    @commethod(14)
    def DrawIndexedInstanced(self, IndexCountPerInstance: UInt32, InstanceCount: UInt32, StartIndexLocation: UInt32, BaseVertexLocation: Int32, StartInstanceLocation: UInt32) -> Void: ...
    @commethod(15)
    def DrawInstanced(self, VertexCountPerInstance: UInt32, InstanceCount: UInt32, StartVertexLocation: UInt32, StartInstanceLocation: UInt32) -> Void: ...
    @commethod(16)
    def GSSetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer)) -> Void: ...
    @commethod(17)
    def GSSetShader(self, pShader: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10GeometryShader) -> Void: ...
    @commethod(18)
    def IASetPrimitiveTopology(self, Topology: win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE_TOPOLOGY) -> Void: ...
    @commethod(19)
    def VSSetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView)) -> Void: ...
    @commethod(20)
    def VSSetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10SamplerState)) -> Void: ...
    @commethod(21)
    def SetPredication(self, pPredicate: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Predicate, PredicateValue: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(22)
    def GSSetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView)) -> Void: ...
    @commethod(23)
    def GSSetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10SamplerState)) -> Void: ...
    @commethod(24)
    def OMSetRenderTargets(self, NumViews: UInt32, ppRenderTargetViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RenderTargetView), pDepthStencilView: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilView) -> Void: ...
    @commethod(25)
    def OMSetBlendState(self, pBlendState: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10BlendState, BlendFactor: POINTER(Single), SampleMask: UInt32) -> Void: ...
    @commethod(26)
    def OMSetDepthStencilState(self, pDepthStencilState: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilState, StencilRef: UInt32) -> Void: ...
    @commethod(27)
    def SOSetTargets(self, NumBuffers: UInt32, ppSOTargets: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer), pOffsets: POINTER(UInt32)) -> Void: ...
    @commethod(28)
    def DrawAuto(self) -> Void: ...
    @commethod(29)
    def RSSetState(self, pRasterizerState: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RasterizerState) -> Void: ...
    @commethod(30)
    def RSSetViewports(self, NumViewports: UInt32, pViewports: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_VIEWPORT)) -> Void: ...
    @commethod(31)
    def RSSetScissorRects(self, NumRects: UInt32, pRects: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(32)
    def CopySubresourceRegion(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource, DstSubresource: UInt32, DstX: UInt32, DstY: UInt32, DstZ: UInt32, pSrcResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource, SrcSubresource: UInt32, pSrcBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BOX)) -> Void: ...
    @commethod(33)
    def CopyResource(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource, pSrcResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource) -> Void: ...
    @commethod(34)
    def UpdateSubresource(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource, DstSubresource: UInt32, pDstBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BOX), pSrcData: VoidPtr, SrcRowPitch: UInt32, SrcDepthPitch: UInt32) -> Void: ...
    @commethod(35)
    def ClearRenderTargetView(self, pRenderTargetView: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RenderTargetView, ColorRGBA: POINTER(Single)) -> Void: ...
    @commethod(36)
    def ClearDepthStencilView(self, pDepthStencilView: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilView, ClearFlags: UInt32, Depth: Single, Stencil: Byte) -> Void: ...
    @commethod(37)
    def GenerateMips(self, pShaderResourceView: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView) -> Void: ...
    @commethod(38)
    def ResolveSubresource(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource, DstSubresource: UInt32, pSrcResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource, SrcSubresource: UInt32, Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT) -> Void: ...
    @commethod(39)
    def VSGetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer)) -> Void: ...
    @commethod(40)
    def PSGetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView)) -> Void: ...
    @commethod(41)
    def PSGetShader(self, ppPixelShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10PixelShader)) -> Void: ...
    @commethod(42)
    def PSGetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10SamplerState)) -> Void: ...
    @commethod(43)
    def VSGetShader(self, ppVertexShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10VertexShader)) -> Void: ...
    @commethod(44)
    def PSGetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer)) -> Void: ...
    @commethod(45)
    def IAGetInputLayout(self, ppInputLayout: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10InputLayout)) -> Void: ...
    @commethod(46)
    def IAGetVertexBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppVertexBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer), pStrides: POINTER(UInt32), pOffsets: POINTER(UInt32)) -> Void: ...
    @commethod(47)
    def IAGetIndexBuffer(self, pIndexBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer), Format: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT), Offset: POINTER(UInt32)) -> Void: ...
    @commethod(48)
    def GSGetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer)) -> Void: ...
    @commethod(49)
    def GSGetShader(self, ppGeometryShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10GeometryShader)) -> Void: ...
    @commethod(50)
    def IAGetPrimitiveTopology(self, pTopology: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE_TOPOLOGY)) -> Void: ...
    @commethod(51)
    def VSGetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView)) -> Void: ...
    @commethod(52)
    def VSGetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10SamplerState)) -> Void: ...
    @commethod(53)
    def GetPredication(self, ppPredicate: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Predicate), pPredicateValue: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Void: ...
    @commethod(54)
    def GSGetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView)) -> Void: ...
    @commethod(55)
    def GSGetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10SamplerState)) -> Void: ...
    @commethod(56)
    def OMGetRenderTargets(self, NumViews: UInt32, ppRenderTargetViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RenderTargetView), ppDepthStencilView: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilView)) -> Void: ...
    @commethod(57)
    def OMGetBlendState(self, ppBlendState: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10BlendState), BlendFactor: POINTER(Single), pSampleMask: POINTER(UInt32)) -> Void: ...
    @commethod(58)
    def OMGetDepthStencilState(self, ppDepthStencilState: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilState), pStencilRef: POINTER(UInt32)) -> Void: ...
    @commethod(59)
    def SOGetTargets(self, NumBuffers: UInt32, ppSOTargets: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer), pOffsets: POINTER(UInt32)) -> Void: ...
    @commethod(60)
    def RSGetState(self, ppRasterizerState: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RasterizerState)) -> Void: ...
    @commethod(61)
    def RSGetViewports(self, NumViewports: POINTER(UInt32), pViewports: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_VIEWPORT)) -> Void: ...
    @commethod(62)
    def RSGetScissorRects(self, NumRects: POINTER(UInt32), pRects: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(63)
    def GetDeviceRemovedReason(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def SetExceptionMode(self, RaiseFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def GetExceptionMode(self) -> UInt32: ...
    @commethod(66)
    def GetPrivateData(self, guid: POINTER(Guid), pDataSize: POINTER(UInt32), pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def SetPrivateData(self, guid: POINTER(Guid), DataSize: UInt32, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def SetPrivateDataInterface(self, guid: POINTER(Guid), pData: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def ClearState(self) -> Void: ...
    @commethod(70)
    def Flush(self) -> Void: ...
    @commethod(71)
    def CreateBuffer(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BUFFER_DESC), pInitialData: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SUBRESOURCE_DATA), ppBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def CreateTexture1D(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE1D_DESC), pInitialData: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SUBRESOURCE_DATA), ppTexture1D: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Texture1D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def CreateTexture2D(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE2D_DESC), pInitialData: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SUBRESOURCE_DATA), ppTexture2D: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Texture2D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def CreateTexture3D(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE3D_DESC), pInitialData: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SUBRESOURCE_DATA), ppTexture3D: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Texture3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def CreateShaderResourceView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_RESOURCE_VIEW_DESC), ppSRView: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def CreateRenderTargetView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RENDER_TARGET_VIEW_DESC), ppRTView: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RenderTargetView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def CreateDepthStencilView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEPTH_STENCIL_VIEW_DESC), ppDepthStencilView: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def CreateInputLayout(self, pInputElementDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INPUT_ELEMENT_DESC), NumElements: UInt32, pShaderBytecodeWithInputSignature: VoidPtr, BytecodeLength: UIntPtr, ppInputLayout: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10InputLayout)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def CreateVertexShader(self, pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, ppVertexShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10VertexShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def CreateGeometryShader(self, pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, ppGeometryShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10GeometryShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def CreateGeometryShaderWithStreamOutput(self, pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, pSODeclaration: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SO_DECLARATION_ENTRY), NumEntries: UInt32, OutputStreamStride: UInt32, ppGeometryShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10GeometryShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def CreatePixelShader(self, pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, ppPixelShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10PixelShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def CreateBlendState(self, pBlendStateDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_DESC), ppBlendState: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10BlendState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def CreateDepthStencilState(self, pDepthStencilDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEPTH_STENCIL_DESC), ppDepthStencilState: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def CreateRasterizerState(self, pRasterizerDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RASTERIZER_DESC), ppRasterizerState: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RasterizerState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def CreateSamplerState(self, pSamplerDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SAMPLER_DESC), ppSamplerState: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10SamplerState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def CreateQuery(self, pQueryDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY_DESC), ppQuery: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Query)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def CreatePredicate(self, pPredicateDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY_DESC), ppPredicate: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Predicate)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def CreateCounter(self, pCounterDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER_DESC), ppCounter: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Counter)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def CheckFormatSupport(self, Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, pFormatSupport: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def CheckMultisampleQualityLevels(self, Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, SampleCount: UInt32, pNumQualityLevels: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def CheckCounterInfo(self, pCounterInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER_INFO)) -> Void: ...
    @commethod(93)
    def CheckCounter(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER_DESC), pType: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_COUNTER_TYPE), pActiveCounters: POINTER(UInt32), szName: win32more.Windows.Win32.Foundation.PSTR, pNameLength: POINTER(UInt32), szUnits: win32more.Windows.Win32.Foundation.PSTR, pUnitsLength: POINTER(UInt32), szDescription: win32more.Windows.Win32.Foundation.PSTR, pDescriptionLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def GetCreationFlags(self) -> UInt32: ...
    @commethod(95)
    def OpenSharedResource(self, hResource: win32more.Windows.Win32.Foundation.HANDLE, ReturnedInterface: POINTER(Guid), ppResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def SetTextFilterSize(self, Width: UInt32, Height: UInt32) -> Void: ...
    @commethod(97)
    def GetTextFilterSize(self, pWidth: POINTER(UInt32), pHeight: POINTER(UInt32)) -> Void: ...
class ID3D10Device1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device
    _iid_ = Guid('{9b7e4c8f-342c-4106-a19f-4f2704f689f0}')
    @commethod(98)
    def CreateShaderResourceView1(self, pResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_RESOURCE_VIEW_DESC1), ppSRView: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def CreateBlendState1(self, pBlendStateDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_DESC1), ppBlendState: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10BlendState1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def GetFeatureLevel(self) -> win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FEATURE_LEVEL1: ...
class ID3D10DeviceChild(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9b7e4c00-342c-4106-a19f-4f2704f689f0}')
    @commethod(3)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device)) -> Void: ...
    @commethod(4)
    def GetPrivateData(self, guid: POINTER(Guid), pDataSize: POINTER(UInt32), pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetPrivateData(self, guid: POINTER(Guid), DataSize: UInt32, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetPrivateDataInterface(self, guid: POINTER(Guid), pData: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10Effect(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{51b0ca8b-ec0b-4519-870d-8ee1cb5017c7}')
    @commethod(3)
    def IsValid(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(4)
    def IsPool(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(5)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_EFFECT_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetConstantBufferByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectConstantBuffer: ...
    @commethod(8)
    def GetConstantBufferByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectConstantBuffer: ...
    @commethod(9)
    def GetVariableByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(10)
    def GetVariableByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(11)
    def GetVariableBySemantic(self, Semantic: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(12)
    def GetTechniqueByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectTechnique: ...
    @commethod(13)
    def GetTechniqueByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectTechnique: ...
    @commethod(14)
    def Optimize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def IsOptimized(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class ID3D10EffectBlendVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{1fcd2294-df6d-4eae-86b3-0e9160cfb07b}')
    @commethod(25)
    def GetBlendState(self, Index: UInt32, ppBlendState: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10BlendState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetBackingStore(self, Index: UInt32, pBlendDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_BLEND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectConstantBuffer(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{56648f4d-cc8b-4444-a5ad-b5a3d76e91b3}')
    @commethod(25)
    def SetConstantBuffer(self, pConstantBuffer: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetConstantBuffer(self, ppConstantBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Buffer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetTextureBuffer(self, pTextureBuffer: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetTextureBuffer(self, ppTextureBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectDepthStencilVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{af482368-330a-46a5-9a5c-01c71af24c8d}')
    @commethod(25)
    def GetDepthStencilState(self, Index: UInt32, ppDepthStencilState: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetBackingStore(self, Index: UInt32, pDepthStencilDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DEPTH_STENCIL_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectDepthStencilViewVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{3e02c918-cc79-4985-b622-2d92ad701623}')
    @commethod(25)
    def SetDepthStencil(self, pResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilView) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetDepthStencil(self, ppResource: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetDepthStencilArray(self, ppResources: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilView), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetDepthStencilArray(self, ppResources: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DepthStencilView), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectMatrixVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{50666c24-b82f-4eed-a172-5b6e7e8522e0}')
    @commethod(25)
    def SetMatrix(self, pData: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetMatrix(self, pData: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetMatrixArray(self, pData: POINTER(Single), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetMatrixArray(self, pData: POINTER(Single), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def SetMatrixTranspose(self, pData: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetMatrixTranspose(self, pData: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetMatrixTransposeArray(self, pData: POINTER(Single), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetMatrixTransposeArray(self, pData: POINTER(Single), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectPass(ComPtr):
    extends: None
    _iid_ = Guid('{5cfbeb89-1a06-46e0-b282-e3f9bfa36a54}')
    @commethod(0)
    def IsValid(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(1)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_PASS_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(2)
    def GetVertexShaderDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_PASS_SHADER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(3)
    def GetGeometryShaderDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_PASS_SHADER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPixelShaderDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_PASS_SHADER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetAnnotationByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(6)
    def GetAnnotationByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(7)
    def Apply(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def ComputeStateBlockMask(self, pStateBlockMask: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectPool(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9537ab04-3250-412e-8213-fcd2f8677933}')
    @commethod(3)
    def AsEffect(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Effect: ...
class ID3D10EffectRasterizerVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{21af9f0e-4d94-4ea9-9785-2cb76b8c0b34}')
    @commethod(25)
    def GetRasterizerState(self, Index: UInt32, ppRasterizerState: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RasterizerState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetBackingStore(self, Index: UInt32, pRasterizerDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RASTERIZER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectRenderTargetViewVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{28ca0cc3-c2c9-40bb-b57f-67b737122b17}')
    @commethod(25)
    def SetRenderTarget(self, pResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RenderTargetView) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetRenderTarget(self, ppResource: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RenderTargetView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetRenderTargetArray(self, ppResources: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RenderTargetView), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetRenderTargetArray(self, ppResources: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10RenderTargetView), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectSamplerVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{6530d5c7-07e9-4271-a418-e7ce4bd1e480}')
    @commethod(25)
    def GetSampler(self, Index: UInt32, ppSampler: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10SamplerState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetBackingStore(self, Index: UInt32, pSamplerDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SAMPLER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectScalarVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{00e48f7b-d2c8-49e8-a86c-022dee53431f}')
    @commethod(25)
    def SetFloat(self, Value: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetFloat(self, pValue: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetFloatArray(self, pData: POINTER(Single), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetFloatArray(self, pData: POINTER(Single), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def SetInt(self, Value: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetInt(self, pValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetIntArray(self, pData: POINTER(Int32), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetIntArray(self, pData: POINTER(Int32), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def SetBool(self, Value: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetBool(self, pValue: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def SetBoolArray(self, pData: POINTER(win32more.Windows.Win32.Foundation.BOOL), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetBoolArray(self, pData: POINTER(win32more.Windows.Win32.Foundation.BOOL), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectShaderResourceVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{c0a7157b-d872-4b1d-8073-efc2acd4b1fc}')
    @commethod(25)
    def SetResource(self, pResource: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetResource(self, ppResource: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetResourceArray(self, ppResources: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetResourceArray(self, ppResources: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectShaderVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{80849279-c799-4797-8c33-0407a07d9e06}')
    @commethod(25)
    def GetShaderDesc(self, ShaderIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_EFFECT_SHADER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetVertexShader(self, ShaderIndex: UInt32, ppVS: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10VertexShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetGeometryShader(self, ShaderIndex: UInt32, ppGS: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10GeometryShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetPixelShader(self, ShaderIndex: UInt32, ppPS: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10PixelShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def GetInputSignatureElementDesc(self, ShaderIndex: UInt32, Element: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetOutputSignatureElementDesc(self, ShaderIndex: UInt32, Element: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectStringVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{71417501-8df9-4e0a-a78a-255f9756baff}')
    @commethod(25)
    def GetString(self, ppString: POINTER(win32more.Windows.Win32.Foundation.PSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetStringArray(self, ppStrings: POINTER(win32more.Windows.Win32.Foundation.PSTR), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectTechnique(ComPtr):
    extends: None
    _iid_ = Guid('{db122ce8-d1c9-4292-b237-24ed3de8b175}')
    @commethod(0)
    def IsValid(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(1)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TECHNIQUE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(2)
    def GetAnnotationByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(3)
    def GetAnnotationByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(4)
    def GetPassByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectPass: ...
    @commethod(5)
    def GetPassByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectPass: ...
    @commethod(6)
    def ComputeStateBlockMask(self, pStateBlockMask: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_STATE_BLOCK_MASK)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectType(ComPtr):
    extends: None
    _iid_ = Guid('{4e9e1ddc-cd9d-4772-a837-00180b9b88fd}')
    @commethod(0)
    def IsValid(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(1)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_EFFECT_TYPE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(2)
    def GetMemberTypeByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectType: ...
    @commethod(3)
    def GetMemberTypeByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectType: ...
    @commethod(4)
    def GetMemberTypeBySemantic(self, Semantic: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectType: ...
    @commethod(5)
    def GetMemberName(self, Index: UInt32) -> win32more.Windows.Win32.Foundation.PSTR: ...
    @commethod(6)
    def GetMemberSemantic(self, Index: UInt32) -> win32more.Windows.Win32.Foundation.PSTR: ...
class ID3D10EffectVariable(ComPtr):
    extends: None
    _iid_ = Guid('{ae897105-00e6-45bf-bb8e-281dd6db8e1b}')
    @commethod(0)
    def IsValid(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(1)
    def GetType(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectType: ...
    @commethod(2)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_EFFECT_VARIABLE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(3)
    def GetAnnotationByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(4)
    def GetAnnotationByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(5)
    def GetMemberByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(6)
    def GetMemberByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(7)
    def GetMemberBySemantic(self, Semantic: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(8)
    def GetElement(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable: ...
    @commethod(9)
    def GetParentConstantBuffer(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectConstantBuffer: ...
    @commethod(10)
    def AsScalar(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectScalarVariable: ...
    @commethod(11)
    def AsVector(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVectorVariable: ...
    @commethod(12)
    def AsMatrix(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectMatrixVariable: ...
    @commethod(13)
    def AsString(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectStringVariable: ...
    @commethod(14)
    def AsShaderResource(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectShaderResourceVariable: ...
    @commethod(15)
    def AsRenderTargetView(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectRenderTargetViewVariable: ...
    @commethod(16)
    def AsDepthStencilView(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectDepthStencilViewVariable: ...
    @commethod(17)
    def AsConstantBuffer(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectConstantBuffer: ...
    @commethod(18)
    def AsShader(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectShaderVariable: ...
    @commethod(19)
    def AsBlend(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectBlendVariable: ...
    @commethod(20)
    def AsDepthStencil(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectDepthStencilVariable: ...
    @commethod(21)
    def AsRasterizer(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectRasterizerVariable: ...
    @commethod(22)
    def AsSampler(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectSamplerVariable: ...
    @commethod(23)
    def SetRawValue(self, pData: VoidPtr, Offset: UInt32, ByteCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetRawValue(self, pData: VoidPtr, Offset: UInt32, ByteCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10EffectVectorVariable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10EffectVariable
    _iid_ = Guid('{62b98c44-1f82-4c67-bcd0-72cf8f217e81}')
    @commethod(25)
    def SetBoolVector(self, pData: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def SetIntVector(self, pData: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetFloatVector(self, pData: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetBoolVector(self, pData: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def GetIntVector(self, pData: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetFloatVector(self, pData: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetBoolVectorArray(self, pData: POINTER(win32more.Windows.Win32.Foundation.BOOL), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetIntVectorArray(self, pData: POINTER(Int32), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def SetFloatVectorArray(self, pData: POINTER(Single), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetBoolVectorArray(self, pData: POINTER(win32more.Windows.Win32.Foundation.BOOL), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetIntVectorArray(self, pData: POINTER(Int32), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetFloatVectorArray(self, pData: POINTER(Single), Offset: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10GeometryShader(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DeviceChild
    _iid_ = Guid('{6316be88-54cd-4040-ab44-20461bc81f68}')
class ID3D10InfoQueue(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1b940b17-2642-4d1f-ab1f-b99bad0c395f}')
    @commethod(3)
    def SetMessageCountLimit(self, MessageCountLimit: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ClearStoredMessages(self) -> Void: ...
    @commethod(5)
    def GetMessage(self, MessageIndex: UInt64, pMessage: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE), pMessageByteLength: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetNumMessagesAllowedByStorageFilter(self) -> UInt64: ...
    @commethod(7)
    def GetNumMessagesDeniedByStorageFilter(self) -> UInt64: ...
    @commethod(8)
    def GetNumStoredMessages(self) -> UInt64: ...
    @commethod(9)
    def GetNumStoredMessagesAllowedByRetrievalFilter(self) -> UInt64: ...
    @commethod(10)
    def GetNumMessagesDiscardedByMessageCountLimit(self) -> UInt64: ...
    @commethod(11)
    def GetMessageCountLimit(self) -> UInt64: ...
    @commethod(12)
    def AddStorageFilterEntries(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetStorageFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INFO_QUEUE_FILTER), pFilterByteLength: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ClearStorageFilter(self) -> Void: ...
    @commethod(15)
    def PushEmptyStorageFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def PushCopyOfStorageFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def PushStorageFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def PopStorageFilter(self) -> Void: ...
    @commethod(19)
    def GetStorageFilterStackSize(self) -> UInt32: ...
    @commethod(20)
    def AddRetrievalFilterEntries(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetRetrievalFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INFO_QUEUE_FILTER), pFilterByteLength: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def ClearRetrievalFilter(self) -> Void: ...
    @commethod(23)
    def PushEmptyRetrievalFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def PushCopyOfRetrievalFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def PushRetrievalFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def PopRetrievalFilter(self) -> Void: ...
    @commethod(27)
    def GetRetrievalFilterStackSize(self) -> UInt32: ...
    @commethod(28)
    def AddMessage(self, Category: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY, Severity: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_SEVERITY, ID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID, pDescription: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def AddApplicationMessage(self, Severity: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_SEVERITY, pDescription: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetBreakOnCategory(self, Category: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetBreakOnSeverity(self, Severity: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_SEVERITY, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetBreakOnID(self, ID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetBreakOnCategory(self, Category: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_CATEGORY) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(34)
    def GetBreakOnSeverity(self, Severity: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_SEVERITY) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(35)
    def GetBreakOnID(self, ID: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MESSAGE_ID) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(36)
    def SetMuteDebugOutput(self, bMute: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(37)
    def GetMuteDebugOutput(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class ID3D10InputLayout(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DeviceChild
    _iid_ = Guid('{9b7e4c0b-342c-4106-a19f-4f2704f689f0}')
class ID3D10Multithread(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9b7e4e00-342c-4106-a19f-4f2704f689f0}')
    @commethod(3)
    def Enter(self) -> Void: ...
    @commethod(4)
    def Leave(self) -> Void: ...
    @commethod(5)
    def SetMultithreadProtected(self, bMTProtect: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(6)
    def GetMultithreadProtected(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class ID3D10PixelShader(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DeviceChild
    _iid_ = Guid('{4968b601-9d00-4cde-8346-8e7f675819b6}')
class ID3D10Predicate(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Query
    _iid_ = Guid('{9b7e4c10-342c-4106-a19f-4f2704f689f0}')
class ID3D10Query(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Asynchronous
    _iid_ = Guid('{9b7e4c0e-342c-4106-a19f-4f2704f689f0}')
    @commethod(11)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_QUERY_DESC)) -> Void: ...
class ID3D10RasterizerState(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DeviceChild
    _iid_ = Guid('{a2a07292-89af-4345-be2e-c53d9fbb6e9f}')
    @commethod(7)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RASTERIZER_DESC)) -> Void: ...
class ID3D10RenderTargetView(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10View
    _iid_ = Guid('{9b7e4c08-342c-4106-a19f-4f2704f689f0}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RENDER_TARGET_VIEW_DESC)) -> Void: ...
class ID3D10Resource(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DeviceChild
    _iid_ = Guid('{9b7e4c01-342c-4106-a19f-4f2704f689f0}')
    @commethod(7)
    def GetType(self, rType: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_RESOURCE_DIMENSION)) -> Void: ...
    @commethod(8)
    def SetEvictionPriority(self, EvictionPriority: UInt32) -> Void: ...
    @commethod(9)
    def GetEvictionPriority(self) -> UInt32: ...
class ID3D10SamplerState(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DeviceChild
    _iid_ = Guid('{9b7e4c0c-342c-4106-a19f-4f2704f689f0}')
    @commethod(7)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SAMPLER_DESC)) -> Void: ...
class ID3D10ShaderReflection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d40e20b6-f8f7-42ad-ab20-4baf8f15dfaa}')
    @commethod(3)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetConstantBufferByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderReflectionConstantBuffer: ...
    @commethod(5)
    def GetConstantBufferByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderReflectionConstantBuffer: ...
    @commethod(6)
    def GetResourceBindingDesc(self, ResourceIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_INPUT_BIND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetInputParameterDesc(self, ParameterIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetOutputParameterDesc(self, ParameterIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10ShaderReflection1(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c3457783-a846-47ce-9520-cea6f66e7447}')
    @commethod(3)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetConstantBufferByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderReflectionConstantBuffer: ...
    @commethod(5)
    def GetConstantBufferByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderReflectionConstantBuffer: ...
    @commethod(6)
    def GetResourceBindingDesc(self, ResourceIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_INPUT_BIND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetInputParameterDesc(self, ParameterIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetOutputParameterDesc(self, ParameterIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetVariableByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderReflectionVariable: ...
    @commethod(10)
    def GetResourceBindingDescByName(self, Name: win32more.Windows.Win32.Foundation.PSTR, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_INPUT_BIND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetMovInstructionCount(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetMovcInstructionCount(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetConversionInstructionCount(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetBitwiseInstructionCount(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetGSInputPrimitive(self, pPrim: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def IsLevel9Shader(self, pbLevel9Shader: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def IsSampleFrequencyShader(self, pbSampleFrequency: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10ShaderReflectionConstantBuffer(ComPtr):
    extends: None
    _iid_ = Guid('{66c66a94-dddd-4b62-a66a-f0da33c2b4d0}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_BUFFER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(1)
    def GetVariableByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderReflectionVariable: ...
    @commethod(2)
    def GetVariableByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderReflectionVariable: ...
class ID3D10ShaderReflectionType(ComPtr):
    extends: None
    _iid_ = Guid('{c530ad7d-9b16-4395-a979-ba2ecff83add}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_TYPE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(1)
    def GetMemberTypeByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderReflectionType: ...
    @commethod(2)
    def GetMemberTypeByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderReflectionType: ...
    @commethod(3)
    def GetMemberTypeName(self, Index: UInt32) -> win32more.Windows.Win32.Foundation.PSTR: ...
class ID3D10ShaderReflectionVariable(ComPtr):
    extends: None
    _iid_ = Guid('{1bf63c95-2650-405d-99c1-3636bd1da0a1}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_VARIABLE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(1)
    def GetType(self) -> win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderReflectionType: ...
class ID3D10ShaderResourceView(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10View
    _iid_ = Guid('{9b7e4c07-342c-4106-a19f-4f2704f689f0}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_RESOURCE_VIEW_DESC)) -> Void: ...
class ID3D10ShaderResourceView1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10ShaderResourceView
    _iid_ = Guid('{9b7e4c87-342c-4106-a19f-4f2704f689f0}')
    @commethod(9)
    def GetDesc1(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_SHADER_RESOURCE_VIEW_DESC1)) -> Void: ...
class ID3D10StateBlock(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0803425a-57f5-4dd6-9465-a87570834a08}')
    @commethod(3)
    def Capture(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Apply(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ReleaseAllDeviceObjects(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D10SwitchToRef(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9b7e4e02-342c-4106-a19f-4f2704f689f0}')
    @commethod(3)
    def SetUseRef(self, UseRef: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(4)
    def GetUseRef(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class ID3D10Texture1D(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource
    _iid_ = Guid('{9b7e4c03-342c-4106-a19f-4f2704f689f0}')
    @commethod(10)
    def Map(self, Subresource: UInt32, MapType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAP, MapFlags: UInt32, ppData: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Unmap(self, Subresource: UInt32) -> Void: ...
    @commethod(12)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE1D_DESC)) -> Void: ...
class ID3D10Texture2D(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource
    _iid_ = Guid('{9b7e4c04-342c-4106-a19f-4f2704f689f0}')
    @commethod(10)
    def Map(self, Subresource: UInt32, MapType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAP, MapFlags: UInt32, pMappedTex2D: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAPPED_TEXTURE2D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Unmap(self, Subresource: UInt32) -> Void: ...
    @commethod(12)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE2D_DESC)) -> Void: ...
class ID3D10Texture3D(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource
    _iid_ = Guid('{9b7e4c05-342c-4106-a19f-4f2704f689f0}')
    @commethod(10)
    def Map(self, Subresource: UInt32, MapType: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAP, MapFlags: UInt32, pMappedTex3D: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_MAPPED_TEXTURE3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Unmap(self, Subresource: UInt32) -> Void: ...
    @commethod(12)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.D3D10_TEXTURE3D_DESC)) -> Void: ...
class ID3D10VertexShader(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DeviceChild
    _iid_ = Guid('{9b7e4c0a-342c-4106-a19f-4f2704f689f0}')
class ID3D10View(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D10.ID3D10DeviceChild
    _iid_ = Guid('{c902b03f-60a7-49ba-9936-2a3ab37a7e33}')
    @commethod(7)
    def GetResource(self, ppResource: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Resource)) -> Void: ...
@winfunctype_pointer
def PFN_D3D10_CREATE_DEVICE1(param0: win32more.Windows.Win32.Graphics.Dxgi.IDXGIAdapter, param1: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DRIVER_TYPE, param2: win32more.Windows.Win32.Foundation.HMODULE, param3: UInt32, param4: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FEATURE_LEVEL1, param5: UInt32, param6: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_D3D10_CREATE_DEVICE_AND_SWAP_CHAIN1(param0: win32more.Windows.Win32.Graphics.Dxgi.IDXGIAdapter, param1: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_DRIVER_TYPE, param2: win32more.Windows.Win32.Foundation.HMODULE, param3: UInt32, param4: win32more.Windows.Win32.Graphics.Direct3D10.D3D10_FEATURE_LEVEL1, param5: UInt32, param6: POINTER(win32more.Windows.Win32.Graphics.Dxgi.DXGI_SWAP_CHAIN_DESC), param7: POINTER(win32more.Windows.Win32.Graphics.Dxgi.IDXGISwapChain), param8: POINTER(win32more.Windows.Win32.Graphics.Direct3D10.ID3D10Device1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)
